/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02691
 |              SERVICES RESEARCH OUTCOMES STUDY, 1995-1996
 |                (DATASET 0003: FOLLOW-UP INTERVIEW DATA)
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE mode      -3='(-3) MISSING' 1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient Methadone Maintenance'
                  4='(4) Outpatient Drug-Free' ;
  VALUE a1ffffff  -3='(-3) MISSING' 1='(1) Male' 2='(2) Female' ;
  VALUE a3ffffff  -3='(-3) MISSING' 57='(57) 57-64' 65='(65) 65-74' 75='(75) 75+' ;
  VALUE a4ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE a4a_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE a4a_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE a4a_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE a4a_4fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE a5ffffff  -3='(-3) MISSING' 1='(1) White' 2='(2) Black or African American'
                  3='(3) Asian or Pacific Islander'
                  4='(4) Alaskan Native, Native American or Ameri'
                  5='(5) OTHER (SPECIFY)' ;
  VALUE a6ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes, diploma' 2='(2) Yes, GED'
                  3='(3) No' 4='(4) NEVER ATTENDED SCHOOL' ;
  VALUE a7ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1st Grade'
                  2='(2) 2nd Grade' 3='(3) 3rd Grade' 4='(4) 4th Grade' 5='(5) 5th Grade'
                  6='(6) 6th Grade' 7='(7) 7th Grade' 8='(8) 8th Grade' 9='(9) 9th Grade'
                  10='(10) 10th Grade' 11='(11) 11th Grade' 12='(12) 12th Grade'
                  13='(13) 1 Year College' 14='(14) 2 Years College'
                  15='(15) 3 Years College' 16='(16) 4 Years College'
                  17='(17) Graduate/Professional School' ;
  VALUE a8ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a8a_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a8a_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a8a_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a8a_4fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a9ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE a9a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE a10fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Excellent' 2='(2) Good'
                  3='(3) Fair' 4='(4) Poor' ;
  VALUE a11fffff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b1ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Yes, dates correct/went to SROS Program'
                  2='(2) Yes, incorrect/went to SROS Program'
                  3='(3) Yes, wrong SROS Program/dates correct'
                  4='(4) No, never went to SROS Program' ;
  VALUE b2ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b2b       -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b4ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b5ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b5a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_1ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_2ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_3ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_4ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_5ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_6ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_7ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_8ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_9ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_10fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_11fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_12fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_13fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b6_14fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b7_1ffff  -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE b7_2ffff  -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE b7_3ffff  -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE b7_4ffff  -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE b7_5ffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b8a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8b       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8c       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8d       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8e       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8f       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b8g       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very important' 2='(2) Somewhat important' 3='(3) Not important'
                  4='(4) NA (Not applicable)' ;
  VALUE b9a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b9b       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b9c       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b9d       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b9e       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b9f       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b10fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b11fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Very much' 2='(2) Somewhat' 3='(3) Not at all'
                  4='(4) DOESNT REMEMBER ANY STAFF PERSON' ;
  VALUE b11a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Very much' 2='(2) Somewhat' 3='(3) Not at all' ;
  VALUE b12fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b12a_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12a_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b12b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b12c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE b13fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b14fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b15fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Excellent' 2='(2) Good' 3='(3) Fair' 4='(4) Poor' ;
  VALUE b16fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b16a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b16b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Too high' 2='(2) The right amount'
                  3='(3) Too low' ;
  VALUE b17fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b18fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Never' 2='(2) Less than one month'
                  3='(3) 1 month to less than 6 months'
                  4='(4) 6 months to less than one year' 5='(5) 1-2 years'
                  6='(6) 3-4 years, or' 7='(7) 5 years or more' ;
  VALUE b18aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b18ab     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than once a week'
                  3='(3) Once a week' 4='(4) More than once a week' ;
  VALUE b18ac     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than once a week'
                  3='(3) Once a week' 4='(4) More than once a week' ;
  VALUE b19a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19c      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19d      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19e      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19f      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19g      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19h      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b19i      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b20fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very helpful' 2='(2) Somewhat helpful'
                  3='(3) Not at all helpful' ;
  VALUE box20a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING'
                  2='(2) USE START/END DATES FROM FACE SHEET FOR' ;
  VALUE b21code   -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) None' 1='(1) One time' 2='(2) Two times'
                  3='(3) Three times' 4='(4) Four times' 5='(5) Five times'
                  6='(6) 6-10 times' 7='(7) 11-15 times' 8='(8) 16-30 times'
                  9='(9) 31 times or more' ;
  VALUE b21byr    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE b21c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very helpful' 2='(2) Somewhat helpful'
                  3='(3) Not at all helpful' ;
  VALUE b21d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b21d2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b21ecod   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One time' 2='(2) Two times' 3='(3) Three times' 4='(4) Four times'
                  5='(5) Five times' 6='(6) 6-10 times' 7='(7) 11-15 times'
                  8='(8) 16-30 times' 9='(9) 31-50' ;
  VALUE b21gy     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE b21h      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very helpful' 2='(2) Somewhat helpful'
                  3='(3) Not at all helpful' ;
  VALUE b22fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE b23a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b23b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b23c      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b23d      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b23e      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b24a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b24b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b24c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b25fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than one month'
                  3='(3) 1 month to less than 6 months'
                  4='(4) 6 months to less than one year' 5='(5) 1-2 years'
                  6='(6) 3-4 years' 7='(7) 5 years or more' ;
  VALUE b25aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b25ab     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b25ac     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b26fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b26a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b27code   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) One time' 2='(2) Two times'
                  3='(3) Three times' 4='(4) Four times' 5='(5) Five times'
                  6='(6) 6-10 times' 7='(7) 11-15 times' 8='(8) 16-30 times'
                  9='(9) 31 times or more' ;
  VALUE b29a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient (non-methadone)' 4='(4) Methadone'
                  5='(5) Something else' ;
  VALUE b29b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one month'
                  2='(2) One month' 3='(3) 2-3 months' 4='(4) 4-5 months' 5='(5) 6-8 months'
                  6='(6) 9-11 months' 7='(7) 12 months or more' ;
  VALUE b29c_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b29c_14f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Inpatient'
                  2='(2) Residential' 3='(3) Outpatient (non-methadone)'
                  4='(4) Methadone' 5='(5) Something else' ;
  VALUE b30b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one month'
                  2='(2) One month' 3='(3) 2-3 months' 4='(4) 4-5 months' 5='(5) 6-8 months'
                  6='(6) 9-11 months' 7='(7) 12 months or more' ;
  VALUE b30c_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b30c_14f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b31a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient (non-methadone)' 4='(4) Methadone'
                  5='(5) Something else' ;
  VALUE b31b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one month' 2='(2) One month' 3='(3) 2-3 months'
                  4='(4) 4-5 months' 5='(5) 6-8 months' 6='(6) 9-11 months'
                  7='(7) 12 months or more' ;
  VALUE b31c_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b31c_14f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 2='(2) No' ;
  VALUE b32a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient (non-methadone)' 4='(4) Methadone'
                  5='(5) Something else' ;
  VALUE b32b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one month' 2='(2) One month' 3='(3) 2-3 months'
                  4='(4) 4-5 months' 5='(5) 6-8 months' 6='(6) 9-11 months'
                  7='(7) 12 months or more' ;
  VALUE b32c_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b32c_14f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 2='(2) No' ;
  VALUE b33a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient (non-methadone)' 4='(4) Methadone' ;
  VALUE b33b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one month' 2='(2) One month' 3='(3) 2-3 months'
                  4='(4) 4-5 months' 5='(5) 6-8 months' 6='(6) 9-11 months'
                  7='(7) 12 months or more' ;
  VALUE b33c_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 2='(2) No' ;
  VALUE b33c_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_11f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_12f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_13f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b33c_14f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b34a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b34b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b34c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b35fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than one month'
                  3='(3) 1 month to less than 6 months'
                  4='(4) 6 months to less than one year' 5='(5) 1-2 years'
                  6='(6) 3-4 years' 7='(7) 5 years or more' ;
  VALUE b35aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b35ab     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b35ac     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Never' 2='(2) Less than once a week' 3='(3) Once a week'
                  4='(4) More than once a week' ;
  VALUE b36fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_4fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_5fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_6fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_7fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_8fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_9fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_10ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_11ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_12ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b41_13ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE b42fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b43fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE b44fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE b44a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Too high'
                  2='(2) The right amount' 3='(3) Too low' ;
  VALUE b45fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE b46fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than one month'
                  3='(3) 1 month to less than 6 months'
                  4='(4) 6 months to less than one year' 5='(5) 1-2 years'
                  6='(6) 3-4 years' 7='(7) 5 years or more' ;
  VALUE b46aa     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than once a week'
                  3='(3) Once a week' 4='(4) More than once a week' ;
  VALUE b46ab     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than once a week'
                  3='(3) Once a week' 4='(4) More than once a week' ;
  VALUE b46ac     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Never' 2='(2) Less than once a week'
                  3='(3) Once a week' 4='(4) More than once a week' ;
  VALUE b47a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47c      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47d      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47e      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47f      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47g      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47h      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b47i      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE b48fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' 3='(3) NA (Not applicable)' ;
  VALUE c1ainhal  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1aalcoh  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1amarij  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1acrack  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1acocai  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1apcp    -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1ahallu  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1aheroi  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1amthdo  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1aonarc  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1ametha  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1adownr  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c1aodrug  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE c2inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3ainhal  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 4='(4) 11-20 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c4inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-5 days'
                  3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c6inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c8inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8ainhal  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-3 months'
                  3='(3) 4-5 months' ;
  VALUE c9inhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 6='(6) Everyday' ;
  VALUE c2alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c3alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c3aalcoh  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c4alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c6alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c8alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c8aalcoh  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) 1 month' 2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months'
                  5='(5) 9+ months' ;
  VALUE c9alcoh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c2marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3amarij  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c7marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8amarij  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9marij   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c2crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3acrack  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8acrack  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9crack   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c2cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3acocai  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c4cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c6cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8acocai  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9cocai   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c2pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3apcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-5 days'
                  3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c4pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 4='(4) 11-20 days' 5='(5) 21-30 days' ;
  VALUE c6pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 5='(5) 21-30 days' ;
  VALUE c8pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' ;
  VALUE c8apcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c9pcp     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 4='(4) 11-20 days' ;
  VALUE c2hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3ahallu  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days' ;
  VALUE c6hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 4='(4) 11-20 days' 5='(5) 21-30 days' ;
  VALUE c8hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8ahallu  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-3 months'
                  3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9hallu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  5='(5) 21-30 days' ;
  VALUE c2heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c3heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c3aheroi  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c4heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c5heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c6heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8aheroi  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9heroi   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c2mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3amthdo  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c4mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-5 days'
                  3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days' ;
  VALUE c6mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-5 days'
                  3='(3) 6-10 days' ;
  VALUE c8mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' ;
  VALUE c8amthdo  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 4='(4) 6-8 months' ;
  VALUE c9mthdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c2onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3aonarc  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8aonarc  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9onarc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 2='(2) 2-5 days'
                  3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days' ;
  VALUE c2metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3ametha  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8ametha  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-3 months'
                  3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9metha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c2downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3adownr  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8downr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8adownr  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2-3 months'
                  3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9downr   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  0='(0) None' 1='(1) One day' 2='(2) 2-5 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c2odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c3odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c3aodrug  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c4odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c5odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c6odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c7odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c8odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c8aodrug  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2-3 months' 3='(3) 4-5 months' 4='(4) 6-8 months' 5='(5) 9+ months' ;
  VALUE c9odrug   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 2='(2) 2-5 days'
                  3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c10fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c11fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c12_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c13_1fff  -6.0='(-6.0) LEGITIMATE SKIP' -3.0='(-3.0) MISSING' -1.0='(-1.0) REFUSED' ;
  VALUE c13_1a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Bottles'
                  2='(2) Cans' 3='(3) Glasses' 4='(4) Six packs' 5='(5) Pints' 6='(6) Quarts'
                  11='(11) Other (SPECIFY)' ;
  VALUE c12_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c13_2fff  -6.0='(-6.0) LEGITIMATE SKIP' -3.0='(-3.0) MISSING' ;
  VALUE c13_2a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Bottles' 3='(3) Glasses'
                  7='(7) Fifths' 11='(11) Other (SPECIFY)' ;
  VALUE c12_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c13_3fff  -6.0='(-6.0) LEGITIMATE SKIP' -3.0='(-3.0) MISSING' -2.0='(-2.0) DON''T KNOW' ;
  VALUE c13_3a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  5='(5) 1/2 Pints' 6='(6) Pints' 7='(7) Quarts' 8='(8) Fifths' 9='(9) Drinks'
                  10='(10) Shots' 11='(11) Other (SPECIFY)' ;
  VALUE c15inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Inhalants' ;
  VALUE c15alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) Alcohol' ;
  VALUE c15mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 3='(3) Marijuana/Hashish' ;
  VALUE c15crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 4='(4) Crack' ;
  VALUE c15coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 5='(5) Cocaine Powder' ;
  VALUE c15pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 6='(6) PCP/Angel Dust' ;
  VALUE c15halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING'
                  7='(7) Hallucinogens/Psychedelics/LSD' ;
  VALUE c15hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 8='(8) Heroin' ;
  VALUE c15mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 9='(9) Illegal Methadone' ;
  VALUE c15onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 10='(10) Other narcotics' ;
  VALUE c15meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 11='(11) Methamphetamines' ;
  VALUE c15down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 12='(12) Downers' ;
  VALUE c15othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 13='(13) Other drug (SPECIFY)' ;
  VALUE c16inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c18inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c18ainha  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19ainha  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c20inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20ainha  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 5='(5) 21-30 days' ;
  VALUE c21inha   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' ;
  VALUE c16alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c17alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c18alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c18aalco  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c19aalco  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c20alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c20aalco  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c21alco   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c16mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c18mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18amari  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19amari  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c20mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20amari  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c21mari   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c16crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18acrck  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19acrck  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c20crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20acrck  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c21crck   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c16coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE c18coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18acoca  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19acoca  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c20coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c20acoca  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c21coca   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c16pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18apcp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19apcp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 6='(6) Everyday' ;
  VALUE c20pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20apcp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' ;
  VALUE c21pcp    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 2='(2) 2-5 days' ;
  VALUE c16halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c18ahalu  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  0='(0) None' 1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days'
                  4='(4) 11-20 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c19halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19ahalu  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  0='(0) None' 1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days'
                  4='(4) 11-20 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c20halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20ahalu  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' ;
  VALUE c21halu   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' ;
  VALUE c16hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c17hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18ahero  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19ahero  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c20hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20ahero  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c21hero   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c16mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c18amtdo  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19amtdo  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  6='(6) Everyday' ;
  VALUE c20mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20amtdo  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c21mtdo   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 3='(3) 6-10 days'
                  4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c16onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c18aonrc  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19aonrc  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c20onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20aonrc  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c21onrc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c16meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18ameth  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19ameth  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c20meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20ameth  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c21meth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' ;
  VALUE c16down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c17down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18adown  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19adown  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c20down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20adown  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c21down   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) One day' 2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days'
                  5='(5) 21-30 days' 6='(6) Everyday' ;
  VALUE c16othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE c17othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE c18othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c18aothr  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c19othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c19aothr  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c20othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c20aothr  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c21othr   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 4='(4) 11-20 days' 6='(6) Everyday' ;
  VALUE c22fffff  -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c23fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c24_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c25_1fff  -6.0='(-6.0) LEGITIMATE SKIP' -3.0='(-3.0) MISSING' ;
  VALUE c25_1a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Bottles' 2='(2) Cans'
                  3='(3) Glasses' 4='(4) Six packs' 6='(6) Quarts' 11='(11) Other (SPECIFY)' ;
  VALUE c24_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c25_2fff  -6.0='(-6.0) LEGITIMATE SKIP' -3.0='(-3.0) MISSING' ;
  VALUE c25_2a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Bottles' 3='(3) Glasses'
                  7='(7) Fifths' 11='(11) Other (SPECIFY)' ;
  VALUE c24_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE c25_3fff  -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' ;
  VALUE c25_3a    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 5='(5) 1/2 Pints' 6='(6) Pints'
                  7='(7) Quarts' 8='(8) Fifths' 9='(9) Drinks' 10='(10) Shots'
                  11='(11) Other (SPECIFY)' ;
  VALUE c27fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE c27a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE c27b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE c28fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) None' 2='(2) 1-9 times' 3='(3) 10-29'
                  4='(4) 30-49 times' 5='(5) 50-99 times' 6='(6) 100-199'
                  7='(7) 200 times or more' 8='(8) R NEVER INJECTED DRUGS' ;
  VALUE c28a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 0='(0) None' 1='(1) One day'
                  2='(2) 2-5 days' 3='(3) 6-10 days' 4='(4) 11-20 days' 5='(5) 21-30 days'
                  6='(6) Everyday' ;
  VALUE c28b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE c28ca     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Very Helpful'
                  2='(2) Somewhat Helpful' 3='(3) Not at all Helpful' ;
  VALUE c28cb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Very Helpful'
                  2='(2) Somewhat Helpful' 3='(3) Not at all Helpful' ;
  VALUE c28cc     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Very Helpful' 2='(2) Somewhat Helpful'
                  3='(3) Not at all Helpful' ;
  VALUE c29fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) None' 2='(2) 1-9 times' 3='(3) 10-29 times'
                  4='(4) 30-49 times' 5='(5) 50-99 times' 6='(6) 100-199 times'
                  7='(7) 200 times or more' 8='(8) R HAS NEVER INJECTED DRUGS' ;
  VALUE c29a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) R HAS NEVER INJECTED DRUGS' ;
  VALUE d1ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d1a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE d2ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) None' 1='(1) One time' 2='(2) Two times'
                  3='(3) Three times' 4='(4) Four times' 5='(5) Five times'
                  6='(6) 6-10 times' 7='(7) 11-15 times' 8='(8) 16-30 times'
                  9='(9) 31-50 times' 10='(10) 51 times or more' ;
  VALUE d3ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) None' 1='(1) One time' 2='(2) Two times'
                  3='(3) Three times' 4='(4) Four times' 5='(5) Five times'
                  6='(6) 6-10 times' 7='(7) 11-15 times' 8='(8) 16-30 times'
                  9='(9) 31-50 times' 10='(10) 51 times or more' ;
  VALUE d4ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d5ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) R NEVER INCARCERATED/UNDER SUPERVISION' ;
  VALUE d6a       -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE d6b       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d6c       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE d6d       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d6e       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d6f       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d6g       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d7ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d7aa      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d7ba      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d7ab      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE d7bb      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE d7ac      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE d7bc      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d7ad      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d7bd      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' ;
  VALUE d7ae      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d7be      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d7af      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d7bf      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d7ag      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d7bg      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' ;
  VALUE d8ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d9a_1fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_2fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_3fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_4fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_5fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_6fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_7fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_8fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_9fff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_10ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_11ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d9a_12ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_13ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_14ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d9a_15ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d10fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d10a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) More' 2='(2) Less' 3='(3) About the same'
                  4='(4) NEVER DID ILLEGAL ACTIVITY BEFORE PROGRA' ;
  VALUE d11fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d12a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13anum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Days' 2='(2) Weeks'
                  3='(3) Months' 4='(4) Years' ;
  VALUE d12b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13bnum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) Weeks' 3='(3) Months'
                  4='(4) Years' ;
  VALUE d12c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13cnum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Days' 3='(3) Months'
                  4='(4) Years' ;
  VALUE d12d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13dnum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Days' 2='(2) Weeks'
                  3='(3) Months' 4='(4) Years' ;
  VALUE d12e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE d13enum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Days'
                  2='(2) Weeks' 3='(3) Months' 4='(4) Years' ;
  VALUE d12f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d13f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13fnum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Days' 2='(2) Weeks'
                  3='(3) Months' 4='(4) Years' ;
  VALUE d12g      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d13g      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE d13gnum   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Days' 2='(2) Weeks'
                  3='(3) Months' ;
  VALUE d14fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 0='(0) NEVER' 1='(1) One time'
                  2='(2) Two time' 3='(3) Three times' 4='(4) Four times' 5='(5) Five times'
                  6='(6) 6-10 times' 7='(7) 11-15 times' 8='(8) 16-30 times'
                  9='(9) 31-50 times' 10='(10) 51 times or more' ;
  VALUE d14a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE d15fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d15a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d15b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one month'
                  2='(2) One month' 3='(3) 2-3 months' 4='(4) 4-5 months' 5='(5) 6-8 months'
                  6='(6) 9-11 months' 7='(7) Twelve months/entire year' ;
  VALUE d16a      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d16b      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE d16c      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' ;
  VALUE d16d      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE d16e      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d16f      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE d16g      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d17g      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Less than one year'
                  2='(2) 1-2 years' 4='(4) 5 years or more' ;
  VALUE d18fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d19fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one year' 2='(2) 1-2 years'
                  3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE d20fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d20a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d20b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d20c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d20d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d20e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d20f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d21fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d21a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d21b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d21c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d21d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d21e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d21f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d22fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d22a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d22b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d22c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d22d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d22e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d22f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d23fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d23a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d23b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d23c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d23d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d23e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d23f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d24a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d24f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d25a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d25f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d26a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d26f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d27fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d27a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d27b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d27c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d27d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d27e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d27f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d28fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d28a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d28b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d28c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d28d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d28e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d28f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d29a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d29f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d30fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d30a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d30b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d30c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d30d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d30e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d30f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d31fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d31a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d31b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d31c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d31d      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d31e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d31f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d32fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d32a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d32b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d32c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d32d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d32e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d32f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d33fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d33a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d33b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d33c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d33d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d33e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d33f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d34fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d34a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d34b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d34c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d34d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d34e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d34f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d35fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d35a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d35b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d35c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d35d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 2='(2) No' ;
  VALUE d35e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d35f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d36fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) R CURRENTLY INCARCERATED' ;
  VALUE d36aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE d36ab     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d36ac     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE d35ad     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE e1ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE e1a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' 3='(3) MARRIAGE WAS ANNULLED' ;
  VALUE e2ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE e3ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' ;
  VALUE e4month   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE e4year    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE e5ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE e6ffffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Less than one year'
                  2='(2) 1-2 years' 3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE e7ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED'
                  1='(1) Activate skip' ;
  VALUE e8a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE e8b       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE e9ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one month' 2='(2) 1-6 months'
                  3='(3) 7-11 months' 4='(4) 1-2 years' 5='(5) 3-5 years'
                  6='(6) More than five years' 7='(7) NONE'
                  8='(8) R WAS NOT LIVING WITH PARTNER' ;
  VALUE e10fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED'
                  1='(1) Less than one month' 2='(2) 1-2 months' 3='(3) 3-4 months'
                  4='(4) 5-6 months' 5='(5) 7-8 months' 6='(6) 9-11 months'
                  7='(7) 12 months/entire year' 8='(8) NONE'
                  9='(9) R WAS NOT LIVING WITH PARTNER' ;
  VALUE f1ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) NEVER KNEW NATURAL MOTHER' ;
  VALUE f2ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) NEVER KNEW NATURAL FATHER' ;
  VALUE f3ffffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes, with parents'
                  2='(2) Yes, with mother only' 3='(3) Yes, with father only' 4='(4) No' ;
  VALUE f3a       -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE f3b       -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' ;
  VALUE f4ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Never w/parents' 2='(2) Never w/mom'
                  3='(3) Never w/dad' 4='(4) Lived w/both' ;
  VALUE f5ffffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 0='(0) NEVER ATTENDED SCHOOL'
                  1='(1) 1st Grade' 2='(2) 2nd Grade' 3='(3) 3rd Grade' 4='(4) 4th Grade'
                  5='(5) 5th Grade' 6='(6) 6th Grade' 7='(7) 7th Grade' 8='(8) 8th Grade'
                  9='(9) 9th Grade' 10='(10) 10th Grade' 11='(11) 11th Grade'
                  12='(12) 12th Grade' 13='(13) 1 Year College' 14='(14) 2 Years College'
                  15='(15) 3 Years College' 16='(16) 4 Years College'
                  17='(17) Graduate/Professional School' ;
  VALUE f5a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes, diploma' 2='(2) Yes, GED' 3='(3) No' ;
  VALUE f6ffffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 0='(0) NEVER ATTENDED SCHOOL'
                  1='(1) 1st Grade' 2='(2) 2nd Grade' 3='(3) 3rd Grade' 4='(4) 4th Grade'
                  5='(5) 5th Grade' 6='(6) 6th Grade' 7='(7) 7th Grade' 8='(8) 8th Grade'
                  9='(9) 9th Grade' 10='(10) 10th Grade' 11='(11) 11th Grade'
                  12='(12) 12th Grade' 13='(13) 1 Year College' 14='(14) 2 Years College'
                  15='(15) 3 Years College' 16='(16) 4 Years College'
                  17='(17) Graduate/Professional School' ;
  VALUE f6a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes, diploma' 2='(2) Yes, GED' 3='(3) No' ;
  VALUE f7ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f8ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f8a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE f9ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f10fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 6='(6) 6+' ;
  VALUE f10a      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f11fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f11a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 6='(6) 6+' ;
  VALUE f12fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f12a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 6='(6) 6+' ;
  VALUE f13fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f13a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) GAVE UP CUSTODY TO GO TO TREATMENT' ;
  VALUE f13b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) REGAINED CUSTODY BY COMPLETING TREATMENT' ;
  VALUE f13c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) GAVE UP CUSTODY TO GO TO TREATMENT' ;
  VALUE f13d      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) REGAINED CUSTODY BY COMPLETING TREATMENT' ;
  VALUE f13e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) GAVE UP CUSTODY TO GO TO TREATMENT' ;
  VALUE f13f      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No'
                  3='(3) REGAINED CUSTODY BY COMPLETING TREATMENT' ;
  VALUE f14fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f14a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 6='(6) 6+' ;
  VALUE f15fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f15a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) In shelters'
                  2='(2) On the street' 3='(3) Both' ;
  VALUE f15b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) Less than 1 month' 2='(2) 1-6 months' 3='(3) 7-12 months'
                  4='(4) 13-18 months' 5='(5) 19-30 months' 6='(6) 31-42 months'
                  7='(7) 43-54 months' 9='(9) HOMELESS IN SHELTERS ENTIRE TIME' ;
  VALUE f15c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) Less that 1 month' 2='(2) 1-6 months' 3='(3) 7-12 months'
                  4='(4) 13-18 months' 5='(5) 19-30 months' 6='(6) 31-42 months'
                  7='(7) 43-54 months' 8='(8) More than 54 months'
                  9='(9) HOMELESS ON STREET ENTIRE TIME' ;
  VALUE f16fffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f16a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) Less than 1 month' 2='(2) 1-6 months' 3='(3) 7-12 months'
                  4='(4) 13-18 months' 5='(5) 19-30 months' 6='(6) 31-42 months'
                  7='(7) 43-54 months' 8='(8) More than 54 months' 9='(9) ENTIRE TIME' ;
  VALUE f17fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE f17a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) In shelters'
                  2='(2) On the street' 3='(3) Both' ;
  VALUE f17b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 0='(0) None' 1='(1) Less than 1 month' 2='(2) 1-6 months'
                  3='(3) 7-12 months' 4='(4) 13-18 months' 5='(5) 19-30 months'
                  6='(6) 31-42 months' 8='(8) More than 54 months'
                  9='(9) HOMELESS IN SHELTERS ENTIRE TIME' ;
  VALUE f17c      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 0='(0) None'
                  1='(1) Less than 1 month' 2='(2) 1-6 months' 3='(3) 7-12 months'
                  4='(4) 13-18 months' 5='(5) 19-30 months' 6='(6) 31-42 months'
                  7='(7) 43-54 months' 8='(8) More than 54 months'
                  9='(9) HOMELESS ON STREET ENTIRE TIME' ;
  VALUE f19fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE f19a_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_9ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19a_10f  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE f19b_0ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_1ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_2ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  2='(2) No' ;
  VALUE f19b_3ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_4ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  2='(2) No' ;
  VALUE f19b_5ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  2='(2) No' ;
  VALUE f19b_6ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_7ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_8ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_9ff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_10f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_11f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_12f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_13f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_14f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_15f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_16f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19b_17f  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE f19c      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g1ffffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g2ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g3ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE g3a       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g3b       -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) All' 2='(2) Some' 3='(3) None' ;
  VALUE g4ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g5ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) All' 2='(2) Some' 3='(3) None'
                  4='(4) R NEVER USED ALCOHOL' ;
  VALUE g6ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g7ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g8ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED ALCOHOL' ;
  VALUE g9ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g10fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g11fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g12fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE g13fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g14fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g15fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g16fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) R NEVER USED ALCOHOL' ;
  VALUE g17fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) R NEVER USED DRUGS' ;
  VALUE g18fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g19fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g20fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Often' 2='(2) Sometimes' 3='(3) Rarely' 4='(4) Never' ;
  VALUE g20a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g20b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' ;
  VALUE g21fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Often' 2='(2) Sometimes' 3='(3) Rarely' 4='(4) Never' ;
  VALUE g22fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED ALCOHOL' ;
  VALUE g23fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g24fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Often' 2='(2) Sometimes' 3='(3) Rarely' 4='(4) Never' ;
  VALUE g25fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED ALCOHOL' ;
  VALUE g26fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g27fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g28fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g28a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g28b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) All' 2='(2) Some' 3='(3) None' ;
  VALUE g29fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g30fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED ALCOHOL' ;
  VALUE g31fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g32fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g33fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED ALCOHOL' ;
  VALUE g34fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) All'
                  2='(2) Some' 3='(3) None' 4='(4) R NEVER USED DRUGS' ;
  VALUE g35fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g36fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g37fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' ;
  VALUE g38fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g39fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g40fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g41fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE g42fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g43fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g44fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g45fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g46fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g47fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g48fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Excellent'
                  2='(2) Good' 3='(3) Fair' 4='(4) Poor' ;
  VALUE g49fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Excellent'
                  2='(2) Good' 3='(3) Fair' 4='(4) Poor' ;
  VALUE g50fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Excellent'
                  2='(2) Good' 3='(3) Fair' 4='(4) Poor' ;
  VALUE g51a      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51b      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51c      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51d      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51e      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51f      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51g      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51h      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51i      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51j      -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51k      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) R IS MALE' ;
  VALUE g51aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51ba     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51ab     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE g51bb     -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) Yes' 2='(2) No' ;
  VALUE g51ac     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g51bc     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51ad     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51bd     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51ae     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51be     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51af     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51bf     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51ag     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51bg     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51ah     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51bh     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51ai     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51bi     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51aj     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51bj     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g51ak     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g51bk     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g52fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g53fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g54fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  100='(100) 100+' ;
  VALUE g55fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g56fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g57fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g58fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  100='(100) 100+' ;
  VALUE g59fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g60fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g61fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g62fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g63fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) One time' 2='(2) 2-9 times' 3='(3) 10-19 times' 4='(4) 20-49 times'
                  5='(5) 50-99 times' 6='(6) 100 or more times' ;
  VALUE g64fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g65fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) One time' 2='(2) 2-9 times' 3='(3) 10-19 times'
                  4='(4) 20-49 times' 5='(5) 50-99 times' 6='(6) 100 or more times' ;
  VALUE g66fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g67fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g68fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE g69fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g70fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE g71fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g72fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g73fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g74fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g75fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g76fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE g77fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) One time'
                  2='(2) 2-9 times' 3='(3) 10-19 times' 4='(4) 20-49 times'
                  5='(5) 50-99 times' 6='(6) More than 100 times'
                  7='(7) NONE/NEVER SAW A DOCTOR' ;
  VALUE g78fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  1='(1) One time' 2='(2) 2-9 times' 3='(3) 10-19 times' 4='(4) 20-49 times'
                  5='(5) 50-99 times' 6='(6) More than 100 times'
                  7='(7) NONE/NEVER SAW A DOCTOR' ;
  VALUE g79fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) One person'
                  2='(2) 2-10 persons' 3='(3) 11-25 persons' 4='(4) 26-100 persons'
                  5='(5) 100-500 persons' 6='(6) More than 500 persons' 7='(7) NONE' ;
  VALUE g80fffff  -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) One person'
                  2='(2) 2-10 persons' 3='(3) 11-25 persons' 4='(4) 26-100 persons'
                  5='(5) 100-500 persons' 6='(6) More than 500 persons' 7='(7) NONE' ;
  VALUE g81fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g82fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g83fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g84fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' 3='(3) RESULTS POSITIVE' 4='(4) RESULTS NEGATIVE' ;
  VALUE g86fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g87fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g88fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g89fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' 3='(3) RESULTS POSITIVE'
                  4='(4) RESULTS NEGATIVE' ;
  VALUE g90fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE g91fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g92fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g93fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) One time' 2='(2) 2-5 times' 3='(3) 6-10 times' 4='(4) 11-25 times'
                  5='(5) 26-100 times' 6='(6) More than 100 times' ;
  VALUE g95fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g96fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g97fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE g98fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE g99fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) One time' 2='(2) 2-5 times' 3='(3) 6-10 times' 4='(4) 11-25 times'
                  5='(5) 26-100 times' 6='(6) More than 100 times' ;
  VALUE h1ffffff  -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) R CURRENTLY HAS FULL-TIME JOB' ;
  VALUE h2ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h3ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one year' 2='(2) 1-2 years'
                  3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE h3bdol    -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' 100000.00='(100000.00) 100000+' ;
  VALUE h3brate   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day'
                  3='(3) Per week' 4='(4) Every two weeks' 5='(5) Bi-monthly' 6='(6) Monthly'
                  7='(7) Per year' ;
  VALUE h4ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one year' 2='(2) 1-2 years'
                  3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE h4adol    -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' 100000.00='(100000.00) 100000+' ;
  VALUE h4arate   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Per hour' 2='(2) Per day' 3='(3) Per week'
                  4='(4) Every two weeks' 5='(5) Bi-monthly' 6='(6) Monthly' 7='(7) Per year' ;
  VALUE same1st   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h6ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No'
                  3='(3) R CURRENTLY HAS FULL-TIME JOB' ;
  VALUE h7ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one year' 2='(2) 1-2 years'
                  3='(3) 3-4 years' 4='(4) 5 years or more' ;
  VALUE same2nd   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h7bdol    -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' 100000.00='(100000.00) 100000+' ;
  VALUE h7arate   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day'
                  3='(3) Per week' 4='(4) Every two weeks' 5='(5) Bi-monthly' 6='(6) Monthly'
                  7='(7) Per year' ;
  VALUE h8ffffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE h8adol    -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' 100000.00='(100000.00) 100000+' ;
  VALUE h8arate   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day'
                  3='(3) Per week' 4='(4) Every two weeks' 5='(5) Bi-monthly' 6='(6) Monthly'
                  7='(7) Per year' ;
  VALUE same3rd   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h10fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h10a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE h10bdol   -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -1.00='(-1.00) REFUSED'
                  100000.00='(100000.00) 100000+' ;
  VALUE h10brte   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day'
                  3='(3) Per week' 4='(4) Every two weeks' 5='(5) Bi-monthly' 6='(6) Monthly'
                  7='(7) Per year' ;
  VALUE same4th   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE h11fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h12fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE h13fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE same5th   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h13bdol   -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h13brte   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day' 3='(3) Per week'
                  4='(4) Every two weeks' 6='(6) Monthly' 7='(7) Per year' ;
  VALUE h14fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE h14adol   -6.00='(-6.00) LEGITIMATE SKIP' -5.00='(-5.00) NOT APPLICABLE'
                  -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW' -1.00='(-1.00) REFUSED' ;
  VALUE h14arte   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day'
                  3='(3) Per week' 4='(4) Every two weeks' 6='(6) Monthly' 7='(7) Per year' ;
  VALUE same6th   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE h15fffff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than one year' 2='(2) 1-2 years'
                  3='(3) 3-4 years' ;
  VALUE same7th   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' 1='(1) Yes' 2='(2) No' ;
  VALUE h15b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  1='(1) Less than one year' 2='(2) 1-2 years' 3='(3) 3-4 years'
                  4='(4) 5 years or more' ;
  VALUE h15cdol   -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h15crte   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day' 3='(3) Per week'
                  4='(4) Every two weeks' 6='(6) Monthly' 7='(7) Per year' ;
  VALUE h17fffff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE h17a      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE h17bdol   -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h17brte   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per hour' 2='(2) Per day' 3='(3) Per week'
                  4='(4) Every two weeks' 6='(6) Monthly' 7='(7) Per year' ;
  VALUE same8th   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h19fffff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_1ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_2ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_4ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_5ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_6ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_7ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19a_8ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE h19b      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Less than half' 2='(2) Half or more' 3='(3) All' ;
  VALUE h21a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22a      -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h22atim   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month'
                  3='(3) Per year' ;
  VALUE h21b      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22b      -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h22btim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22c      -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h22ctim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21d      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22d      -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h22dtim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21e      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22e      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE h22etim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21f      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22f      -6.00='(-6.00) LEGITIMATE SKIP' -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW'
                  -1.00='(-1.00) REFUSED' ;
  VALUE h22ftim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21g      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22g      -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' ;
  VALUE h22gtim   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month' 3='(3) Per year' ;
  VALUE h21h      -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE h22h      -6.00='(-6.00) LEGITIMATE SKIP' -5.00='(-5.00) NOT APPLICABLE'
                  -3.00='(-3.00) MISSING' -2.00='(-2.00) DON''T KNOW' -1.00='(-1.00) REFUSED' ;
  VALUE h22htim   -6='(-6) LEGITIMATE SKIP' -5='(-5) NOT APPLICABLE' -3='(-3) MISSING'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Per week' 2='(2) Per month'
                  3='(3) Per year' ;
  VALUE phone1ff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED'
                  1='(1) Telephone present' 2='(2) No telephone' ;
  VALUE phone2ff  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Telephone present' 2='(2) No telephone' ;
  VALUE person2f  -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE phone3ff  -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Telephone present' 2='(2) No telephone' ;
  VALUE endyear   -3='(-3) MISSING' ;
  VALUE tottime   -3='(-3) MISSING' ;
  VALUE boxii     -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE boxiii    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE boxiv     -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE boxrecpt  -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11a      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE i11aa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11ab     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE i11b      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE i11ba     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11bb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE i11c      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11ca     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11cb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE i11d      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE i11da     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11db     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11e      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11ea     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11eb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE i11f      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSED' 1='(1) Yes' 2='(2) No' ;
  VALUE i11fa     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11fb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' -2='(-2) DON''T KNOW' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11g      -5='(-5) NOT APPLICABLE' -3='(-3) MISSING' -1='(-1) REFUSED' 1='(1) Yes'
                  2='(2) No' ;
  VALUE i11ga     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Medical'
                  2='(2) Non-medical' ;
  VALUE i11gb     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE i11ac     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE i11bc     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE i11cc     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE i11dc     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE i11ec     -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE i11fc     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE i11gc     -3='(-3) MISSING' 1='(1) Positive' 2='(2) Negative' 3='(3) Refused'
                  4='(4) Not Possible' 6='(6) Invalid Specimen' 7='(7) Lost Specimen' ;
  VALUE d6a_1fff  -3='(-3) MISSING' -2='(-2) DON''T KNOW' ;
  VALUE inhal     -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE alcohol   -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE marijuan  -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE crack     -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE cocaine   -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE pcp       -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE hallucin  -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE heroin    -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE illmeth   -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE narc      -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE methamph  -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE downers   -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE othdrug   -3='(-3) MISSING' 0='(0) Never used (or used less than 5 times)'
                  1='(1) Used as main drug at time entering tx'
                  2='(2) Used as main drug at other time'
                  3='(3) Used but not as main drug' ;
  VALUE agefinh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefalc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefmar   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agfcrk    -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefcoc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefpcp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefher   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefmth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefnar   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefamp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefdwn   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE agefoth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE usbinh    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbalc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbmar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbcrk    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbcoc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbpcp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbhal    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbher    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbmth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbnar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbamp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbdwn    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usboth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbdinh   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdalc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdmar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdcrk   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdcoc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdpcp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdhal   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdher   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdmth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdnar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdamp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbddwn   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usbdoth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usainh    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usaalc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usamar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usacrk    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usacoc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usapcp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usahal    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usaher    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usamth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usanar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usaamp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usadwn    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usaoth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usadinh   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadalc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadmar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadcrk   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadcoc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadpcp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadhal   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadher   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadmth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadnar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadamp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usaddwn   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usadoth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usyinh    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usyalc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usymar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usycrk    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usycoc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usypcp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usyhal    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usyher    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usymth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usynar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usyamp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usydwn    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usyoth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usydinh   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  4='(4) 11 to 20 days/month' 5='(5) 21 to 31 days/month'
                  6='(6) Every day' ;
  VALUE usydalc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydmar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydcrk   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydcoc   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydpcp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 5='(5) 21 to 31 days/month' ;
  VALUE usydhal   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' ;
  VALUE usydher   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydmth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  6='(6) Every day' ;
  VALUE usydnar   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydamp   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usyddwn   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usydoth   -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usninh    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnalc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnmar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usncrk    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usncoc    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnpcp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnhal    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnher    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnmth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnnar    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnamp    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usndwn    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnoth    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usnminh   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2 to 3 months'
                  3='(3) 4 to 5 months' ;
  VALUE usnmalc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmmar   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmcrk   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmcoc   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmpcp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' ;
  VALUE usnmhal   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2 to 3 months'
                  3='(3) 4 to 5 months' 4='(4) 6 to 8 months' 5='(5) 9 or more months' ;
  VALUE usnmher   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmmth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 4='(4) 6 to 8 months' ;
  VALUE usnmnar   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usnmamp   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2 to 3 months'
                  3='(3) 4 to 5 months' 4='(4) 6 to 8 months' 5='(5) 9 or more months' ;
  VALUE usnmdwn   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 2='(2) 2 to 3 months'
                  3='(3) 4 to 5 months' 4='(4) 6 to 8 months' 5='(5) 9 or more months' ;
  VALUE usnmoth   -6='(-6) LEGITIMATE SKIP' -3='(-3) MISSING' 1='(1) 1 month'
                  2='(2) 2 to 3 months' 3='(3) 4 to 5 months' 4='(4) 6 to 8 months'
                  5='(5) 9 or more months' ;
  VALUE usminh    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month' 6='(6) Every day' ;
  VALUE usmalc    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmmar    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmcrk    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmcoc    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmpcp    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  2='(2) 2 to 5 days/month' 4='(4) 11 to 20 days/month' ;
  VALUE usmhal    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 5='(5) 21 to 31 days/month' ;
  VALUE usmher    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmmth    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  6='(6) Every day' ;
  VALUE usmnar    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmamp    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmdwn    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  1='(1) 1 day/month' 2='(2) 2 to 5 days/month'
                  3='(3) 6 to 10 days/month' 4='(4) 11 to 20 days/month'
                  5='(5) 21 to 31 days/month' 6='(6) Every day' ;
  VALUE usmoth    -3='(-3) MISSING' 0='(0) Did not use five times or more'
                  2='(2) 2 to 5 days/month' 3='(3) 6 to 10 days/month'
                  4='(4) 11 to 20 days/month' 6='(6) Every day' ;
  VALUE usbsec    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usasec    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usbany    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE usaany    -3='(-3) MISSING' 0='(0) No' 1='(1) Yes' ;
  VALUE trtype    -3='(-3) MISSING' 1='(1) Inpatient' 2='(2) Residential'
                  3='(3) Outpatient Methadone Maintenance'
                  4='(4) Outpatient Drug-Free' ;
  VALUE los       -3='(-3) MISSING' 1825='(1825) 1825+' ;
  VALUE loscat    -3='(-3) MISSING' 1='(1) Less than 1 week'
                  2='(2) 1 week to less than 1 month' 3='(3) 1 to 5 months'
                  4='(4) 6 months or more' ;
  VALUE race      -3='(-3) MISSING' 1='(1) White (non-Hispanic)'
                  2='(2) Black (non-Hispanic)' 3='(3) Hispanic' 4='(4) Other' ;
  VALUE disage    -3='(-3) MISSING' 75='(75) 75+' ;
  VALUE disage2f  -3='(-3) MISSING' 1='(1) Less than 18' 2='(2) 18 to 29' 3='(3) 30 to 39'
                  4='(4) 40 or older' ;
  VALUE pretrt    -3='(-3) MISSING' 1='(1) 0' 2='(2) 1 to 2' 3='(3) 3 or more' ;
  VALUE comptrt   -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE afttrt    -3='(-3) MISSING' 1='(1) Yes' 2='(2) No' ;
  VALUE helptrt   -3='(-3) MISSING' 1='(1) Very helpful' 2='(2) Somewhat/not helpful' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CLIENTID <= -1) THEN CLIENTID = .;
   IF (FAC_ID <= -1) THEN FAC_ID = .;
   IF (MODE <= -1) THEN MODE = .;
   IF (WT1 <= -1.0000) THEN WT1 = .;
   IF (WT2 <= -1.0000) THEN WT2 = .;
   IF (WT3 <= -1.0000) THEN WT3 = .;
   IF (A1 <= -1) THEN A1 = .;
   IF (A3 <= -1) THEN A3 = .;
   IF (A4 <= -1) THEN A4 = .;
   IF (A4A_1 <= -1) THEN A4A_1 = .;
   IF (A4A_2 <= -1) THEN A4A_2 = .;
   IF (A4A_3 <= -1) THEN A4A_3 = .;
   IF (A4A_4 <= -1) THEN A4A_4 = .;
   IF (A5 <= -1) THEN A5 = .;
   IF (A6 <= -1) THEN A6 = .;
   IF (A7 <= -1) THEN A7 = .;
   IF (A8 <= -1) THEN A8 = .;
   IF (A8A_1 <= -1) THEN A8A_1 = .;
   IF (A8A_2 <= -1) THEN A8A_2 = .;
   IF (A8A_3 <= -1) THEN A8A_3 = .;
   IF (A8A_4 <= -1) THEN A8A_4 = .;
   IF (A9 <= -1) THEN A9 = .;
   IF (A9A <= -1) THEN A9A = .;
   IF (A10 <= -1) THEN A10 = .;
   IF (A11 <= -1) THEN A11 = .;
   IF (B1 <= -1) THEN B1 = .;
   IF (B2 <= -1) THEN B2 = .;
   IF (B2B <= -1) THEN B2B = .;
   IF (B4 <= -1) THEN B4 = .;
   IF (B5 <= -1) THEN B5 = .;
   IF (B5A <= -1) THEN B5A = .;
   IF (B6_1 <= -1) THEN B6_1 = .;
   IF (B6_2 <= -1) THEN B6_2 = .;
   IF (B6_3 <= -1) THEN B6_3 = .;
   IF (B6_4 <= -1) THEN B6_4 = .;
   IF (B6_5 <= -1) THEN B6_5 = .;
   IF (B6_6 <= -1) THEN B6_6 = .;
   IF (B6_7 <= -1) THEN B6_7 = .;
   IF (B6_8 <= -1) THEN B6_8 = .;
   IF (B6_9 <= -1) THEN B6_9 = .;
   IF (B6_10 <= -1) THEN B6_10 = .;
   IF (B6_11 <= -1) THEN B6_11 = .;
   IF (B6_12 <= -1) THEN B6_12 = .;
   IF (B6_13 <= -1) THEN B6_13 = .;
   IF (B6_14 <= -1) THEN B6_14 = .;
   IF (B7_1 <= -1) THEN B7_1 = .;
   IF (B7_2 <= -1) THEN B7_2 = .;
   IF (B7_3 <= -1) THEN B7_3 = .;
   IF (B7_4 <= -1) THEN B7_4 = .;
   IF (B7_5 <= -1) THEN B7_5 = .;
   IF (B8A <= -1) THEN B8A = .;
   IF (B8B <= -1) THEN B8B = .;
   IF (B8C <= -1) THEN B8C = .;
   IF (B8D <= -1) THEN B8D = .;
   IF (B8E <= -1) THEN B8E = .;
   IF (B8F <= -1) THEN B8F = .;
   IF (B8G <= -1) THEN B8G = .;
   IF (B9A <= -1) THEN B9A = .;
   IF (B9B <= -1) THEN B9B = .;
   IF (B9C <= -1) THEN B9C = .;
   IF (B9D <= -1) THEN B9D = .;
   IF (B9E <= -1) THEN B9E = .;
   IF (B9F <= -1) THEN B9F = .;
   IF (B10 <= -1) THEN B10 = .;
   IF (B11 <= -1) THEN B11 = .;
   IF (B11A <= -1) THEN B11A = .;
   IF (B12 <= -1) THEN B12 = .;
   IF (B12A_1 <= -1) THEN B12A_1 = .;
   IF (B12A_2 <= -1) THEN B12A_2 = .;
   IF (B12A_3 <= -1) THEN B12A_3 = .;
   IF (B12A_4 <= -1) THEN B12A_4 = .;
   IF (B12A_5 <= -1) THEN B12A_5 = .;
   IF (B12A_6 <= -1) THEN B12A_6 = .;
   IF (B12A_7 <= -1) THEN B12A_7 = .;
   IF (B12A_8 <= -1) THEN B12A_8 = .;
   IF (B12A_9 <= -1) THEN B12A_9 = .;
   IF (B12A_10 <= -1) THEN B12A_10 = .;
   IF (B12A_11 <= -1) THEN B12A_11 = .;
   IF (B12A_12 <= -1) THEN B12A_12 = .;
   IF (B12A_13 <= -1) THEN B12A_13 = .;
   IF (B12B <= -1) THEN B12B = .;
   IF (B12C <= -1) THEN B12C = .;
   IF (B13 <= -1) THEN B13 = .;
   IF (B14 <= -1) THEN B14 = .;
   IF (B15 <= -1) THEN B15 = .;
   IF (B16 <= -1) THEN B16 = .;
   IF (B16A <= -1) THEN B16A = .;
   IF (B16B <= -1) THEN B16B = .;
   IF (B17 <= -1) THEN B17 = .;
   IF (B18 <= -1) THEN B18 = .;
   IF (B18AA <= -1) THEN B18AA = .;
   IF (B18AB <= -1) THEN B18AB = .;
   IF (B18AC <= -1) THEN B18AC = .;
   IF (B19A <= -1) THEN B19A = .;
   IF (B19B <= -1) THEN B19B = .;
   IF (B19C <= -1) THEN B19C = .;
   IF (B19D <= -1) THEN B19D = .;
   IF (B19E <= -1) THEN B19E = .;
   IF (B19F <= -1) THEN B19F = .;
   IF (B19G <= -1) THEN B19G = .;
   IF (B19H <= -1) THEN B19H = .;
   IF (B19I <= -1) THEN B19I = .;
   IF (B20 <= -1) THEN B20 = .;
   IF (BOX20A <= -1) THEN BOX20A = .;
   IF (B21CODE <= -1) THEN B21CODE = .;
   IF (B21BYR <= -1) THEN B21BYR = .;
   IF (B21C <= -1) THEN B21C = .;
   IF (B21D <= -1) THEN B21D = .;
   IF (B21D2 <= -1) THEN B21D2 = .;
   IF (B21ECOD <= -1) THEN B21ECOD = .;
   IF (B21GY <= -1) THEN B21GY = .;
   IF (B21H <= -1) THEN B21H = .;
   IF (B22 <= -1) THEN B22 = .;
   IF (B23A <= -1) THEN B23A = .;
   IF (B23B <= -1) THEN B23B = .;
   IF (B23C <= -1) THEN B23C = .;
   IF (B23D <= -1) THEN B23D = .;
   IF (B23E <= -1) THEN B23E = .;
   IF (B24A <= -1) THEN B24A = .;
   IF (B24B <= -1) THEN B24B = .;
   IF (B24C <= -1) THEN B24C = .;
   IF (B25 <= -1) THEN B25 = .;
   IF (B25AA <= -1) THEN B25AA = .;
   IF (B25AB <= -1) THEN B25AB = .;
   IF (B25AC <= -1) THEN B25AC = .;
   IF (B26 <= -1) THEN B26 = .;
   IF (B26A <= -1) THEN B26A = .;
   IF (B27CODE <= -1) THEN B27CODE = .;
   IF (B29A <= -1) THEN B29A = .;
   IF (B29B <= -1) THEN B29B = .;
   IF (B29C_1 <= -1) THEN B29C_1 = .;
   IF (B29C_2 <= -1) THEN B29C_2 = .;
   IF (B29C_3 <= -1) THEN B29C_3 = .;
   IF (B29C_4 <= -1) THEN B29C_4 = .;
   IF (B29C_5 <= -1) THEN B29C_5 = .;
   IF (B29C_6 <= -1) THEN B29C_6 = .;
   IF (B29C_7 <= -1) THEN B29C_7 = .;
   IF (B29C_8 <= -1) THEN B29C_8 = .;
   IF (B29C_9 <= -1) THEN B29C_9 = .;
   IF (B29C_10 <= -1) THEN B29C_10 = .;
   IF (B29C_11 <= -1) THEN B29C_11 = .;
   IF (B29C_12 <= -1) THEN B29C_12 = .;
   IF (B29C_13 <= -1) THEN B29C_13 = .;
   IF (B29C_14 <= -1) THEN B29C_14 = .;
   IF (B30A <= -1) THEN B30A = .;
   IF (B30B <= -1) THEN B30B = .;
   IF (B30C_1 <= -1) THEN B30C_1 = .;
   IF (B30C_2 <= -1) THEN B30C_2 = .;
   IF (B30C_3 <= -1) THEN B30C_3 = .;
   IF (B30C_4 <= -1) THEN B30C_4 = .;
   IF (B30C_5 <= -1) THEN B30C_5 = .;
   IF (B30C_6 <= -1) THEN B30C_6 = .;
   IF (B30C_7 <= -1) THEN B30C_7 = .;
   IF (B30C_8 <= -1) THEN B30C_8 = .;
   IF (B30C_9 <= -1) THEN B30C_9 = .;
   IF (B30C_10 <= -1) THEN B30C_10 = .;
   IF (B30C_11 <= -1) THEN B30C_11 = .;
   IF (B30C_12 <= -1) THEN B30C_12 = .;
   IF (B30C_13 <= -1) THEN B30C_13 = .;
   IF (B30C_14 <= -1) THEN B30C_14 = .;
   IF (B31A <= -1) THEN B31A = .;
   IF (B31B <= -1) THEN B31B = .;
   IF (B31C_1 <= -1) THEN B31C_1 = .;
   IF (B31C_2 <= -1) THEN B31C_2 = .;
   IF (B31C_3 <= -1) THEN B31C_3 = .;
   IF (B31C_4 <= -1) THEN B31C_4 = .;
   IF (B31C_5 <= -1) THEN B31C_5 = .;
   IF (B31C_6 <= -1) THEN B31C_6 = .;
   IF (B31C_7 <= -1) THEN B31C_7 = .;
   IF (B31C_8 <= -1) THEN B31C_8 = .;
   IF (B31C_9 <= -1) THEN B31C_9 = .;
   IF (B31C_10 <= -1) THEN B31C_10 = .;
   IF (B31C_11 <= -1) THEN B31C_11 = .;
   IF (B31C_12 <= -1) THEN B31C_12 = .;
   IF (B31C_13 <= -1) THEN B31C_13 = .;
   IF (B31C_14 <= -1) THEN B31C_14 = .;
   IF (B32A <= -1) THEN B32A = .;
   IF (B32B <= -1) THEN B32B = .;
   IF (B32C_1 <= -1) THEN B32C_1 = .;
   IF (B32C_2 <= -1) THEN B32C_2 = .;
   IF (B32C_3 <= -1) THEN B32C_3 = .;
   IF (B32C_4 <= -1) THEN B32C_4 = .;
   IF (B32C_5 <= -1) THEN B32C_5 = .;
   IF (B32C_6 <= -1) THEN B32C_6 = .;
   IF (B32C_7 <= -1) THEN B32C_7 = .;
   IF (B32C_8 <= -1) THEN B32C_8 = .;
   IF (B32C_9 <= -1) THEN B32C_9 = .;
   IF (B32C_10 <= -1) THEN B32C_10 = .;
   IF (B32C_11 <= -1) THEN B32C_11 = .;
   IF (B32C_12 <= -1) THEN B32C_12 = .;
   IF (B32C_13 <= -1) THEN B32C_13 = .;
   IF (B32C_14 <= -1) THEN B32C_14 = .;
   IF (B33A <= -1) THEN B33A = .;
   IF (B33B <= -1) THEN B33B = .;
   IF (B33C_1 <= -1) THEN B33C_1 = .;
   IF (B33C_2 <= -1) THEN B33C_2 = .;
   IF (B33C_3 <= -1) THEN B33C_3 = .;
   IF (B33C_4 <= -1) THEN B33C_4 = .;
   IF (B33C_5 <= -1) THEN B33C_5 = .;
   IF (B33C_6 <= -1) THEN B33C_6 = .;
   IF (B33C_7 <= -1) THEN B33C_7 = .;
   IF (B33C_8 <= -1) THEN B33C_8 = .;
   IF (B33C_9 <= -1) THEN B33C_9 = .;
   IF (B33C_10 <= -1) THEN B33C_10 = .;
   IF (B33C_11 <= -1) THEN B33C_11 = .;
   IF (B33C_12 <= -1) THEN B33C_12 = .;
   IF (B33C_13 <= -1) THEN B33C_13 = .;
   IF (B33C_14 <= -1) THEN B33C_14 = .;
   IF (B34A <= -1) THEN B34A = .;
   IF (B34B <= -1) THEN B34B = .;
   IF (B34C <= -1) THEN B34C = .;
   IF (B35 <= -1) THEN B35 = .;
   IF (B35AA <= -1) THEN B35AA = .;
   IF (B35AB <= -1) THEN B35AB = .;
   IF (B35AC <= -1) THEN B35AC = .;
   IF (B36 <= -1) THEN B36 = .;
   IF (B41_1 <= -1) THEN B41_1 = .;
   IF (B41_2 <= -1) THEN B41_2 = .;
   IF (B41_3 <= -1) THEN B41_3 = .;
   IF (B41_4 <= -1) THEN B41_4 = .;
   IF (B41_5 <= -1) THEN B41_5 = .;
   IF (B41_6 <= -1) THEN B41_6 = .;
   IF (B41_7 <= -1) THEN B41_7 = .;
   IF (B41_8 <= -1) THEN B41_8 = .;
   IF (B41_9 <= -1) THEN B41_9 = .;
   IF (B41_10 <= -1) THEN B41_10 = .;
   IF (B41_11 <= -1) THEN B41_11 = .;
   IF (B41_12 <= -1) THEN B41_12 = .;
   IF (B41_13 <= -1) THEN B41_13 = .;
   IF (B42 <= -1) THEN B42 = .;
   IF (B43 <= -1) THEN B43 = .;
   IF (B44 <= -1) THEN B44 = .;
   IF (B44A <= -1) THEN B44A = .;
   IF (B45 <= -1) THEN B45 = .;
   IF (B46 <= -1) THEN B46 = .;
   IF (B46AA <= -1) THEN B46AA = .;
   IF (B46AB <= -1) THEN B46AB = .;
   IF (B46AC <= -1) THEN B46AC = .;
   IF (B47A <= -1) THEN B47A = .;
   IF (B47B <= -1) THEN B47B = .;
   IF (B47C <= -1) THEN B47C = .;
   IF (B47D <= -1) THEN B47D = .;
   IF (B47E <= -1) THEN B47E = .;
   IF (B47F <= -1) THEN B47F = .;
   IF (B47G <= -1) THEN B47G = .;
   IF (B47H <= -1) THEN B47H = .;
   IF (B47I <= -1) THEN B47I = .;
   IF (B48 <= -1) THEN B48 = .;
   IF (C1AINHAL <= -1) THEN C1AINHAL = .;
   IF (C1AALCOH <= -1) THEN C1AALCOH = .;
   IF (C1AMARIJ <= -1) THEN C1AMARIJ = .;
   IF (C1ACRACK <= -1) THEN C1ACRACK = .;
   IF (C1ACOCAI <= -1) THEN C1ACOCAI = .;
   IF (C1APCP <= -1) THEN C1APCP = .;
   IF (C1AHALLU <= -1) THEN C1AHALLU = .;
   IF (C1AHEROI <= -1) THEN C1AHEROI = .;
   IF (C1AMTHDO <= -1) THEN C1AMTHDO = .;
   IF (C1AONARC <= -1) THEN C1AONARC = .;
   IF (C1AMETHA <= -1) THEN C1AMETHA = .;
   IF (C1ADOWNR <= -1) THEN C1ADOWNR = .;
   IF (C1AODRUG <= -1) THEN C1AODRUG = .;
   IF (C2INHAL <= -1) THEN C2INHAL = .;
   IF (C3INHAL <= -1) THEN C3INHAL = .;
   IF (C3AINHAL <= -1) THEN C3AINHAL = .;
   IF (C4INHAL <= -1) THEN C4INHAL = .;
   IF (C5INHAL <= -1) THEN C5INHAL = .;
   IF (C6INHAL <= -1) THEN C6INHAL = .;
   IF (C7INHAL <= -1) THEN C7INHAL = .;
   IF (C8INHAL <= -1) THEN C8INHAL = .;
   IF (C8AINHAL <= -1) THEN C8AINHAL = .;
   IF (C9INHAL <= -1) THEN C9INHAL = .;
   IF (C2ALCOH <= -1) THEN C2ALCOH = .;
   IF (C3ALCOH <= -1) THEN C3ALCOH = .;
   IF (C3AALCOH <= -1) THEN C3AALCOH = .;
   IF (C4ALCOH <= -1) THEN C4ALCOH = .;
   IF (C5ALCOH <= -1) THEN C5ALCOH = .;
   IF (C6ALCOH <= -1) THEN C6ALCOH = .;
   IF (C7ALCOH <= -1) THEN C7ALCOH = .;
   IF (C8ALCOH <= -1) THEN C8ALCOH = .;
   IF (C8AALCOH <= -1) THEN C8AALCOH = .;
   IF (C9ALCOH <= -1) THEN C9ALCOH = .;
   IF (C2MARIJ <= -1) THEN C2MARIJ = .;
   IF (C3MARIJ <= -1) THEN C3MARIJ = .;
   IF (C3AMARIJ <= -1) THEN C3AMARIJ = .;
   IF (C4MARIJ <= -1) THEN C4MARIJ = .;
   IF (C5MARIJ <= -1) THEN C5MARIJ = .;
   IF (C6MARIJ <= -1) THEN C6MARIJ = .;
   IF (C7MARIJ <= -1) THEN C7MARIJ = .;
   IF (C8MARIJ <= -1) THEN C8MARIJ = .;
   IF (C8AMARIJ <= -1) THEN C8AMARIJ = .;
   IF (C9MARIJ <= -1) THEN C9MARIJ = .;
   IF (C2CRACK <= -1) THEN C2CRACK = .;
   IF (C3CRACK <= -1) THEN C3CRACK = .;
   IF (C3ACRACK <= -1) THEN C3ACRACK = .;
   IF (C4CRACK <= -1) THEN C4CRACK = .;
   IF (C5CRACK <= -1) THEN C5CRACK = .;
   IF (C6CRACK <= -1) THEN C6CRACK = .;
   IF (C7CRACK <= -1) THEN C7CRACK = .;
   IF (C8CRACK <= -1) THEN C8CRACK = .;
   IF (C8ACRACK <= -1) THEN C8ACRACK = .;
   IF (C9CRACK <= -1) THEN C9CRACK = .;
   IF (C2COCAI <= -1) THEN C2COCAI = .;
   IF (C3COCAI <= -1) THEN C3COCAI = .;
   IF (C3ACOCAI <= -1) THEN C3ACOCAI = .;
   IF (C4COCAI <= -1) THEN C4COCAI = .;
   IF (C5COCAI <= -1) THEN C5COCAI = .;
   IF (C6COCAI <= -1) THEN C6COCAI = .;
   IF (C7COCAI <= -1) THEN C7COCAI = .;
   IF (C8COCAI <= -1) THEN C8COCAI = .;
   IF (C8ACOCAI <= -1) THEN C8ACOCAI = .;
   IF (C9COCAI <= -1) THEN C9COCAI = .;
   IF (C2PCP <= -1) THEN C2PCP = .;
   IF (C3PCP <= -1) THEN C3PCP = .;
   IF (C3APCP <= -1) THEN C3APCP = .;
   IF (C4PCP <= -1) THEN C4PCP = .;
   IF (C5PCP <= -1) THEN C5PCP = .;
   IF (C6PCP <= -1) THEN C6PCP = .;
   IF (C7PCP <= -1) THEN C7PCP = .;
   IF (C8PCP <= -1) THEN C8PCP = .;
   IF (C8APCP <= -1) THEN C8APCP = .;
   IF (C9PCP <= -1) THEN C9PCP = .;
   IF (C2HALLU <= -1) THEN C2HALLU = .;
   IF (C3HALLU <= -1) THEN C3HALLU = .;
   IF (C3AHALLU <= -1) THEN C3AHALLU = .;
   IF (C4HALLU <= -1) THEN C4HALLU = .;
   IF (C5HALLU <= -1) THEN C5HALLU = .;
   IF (C6HALLU <= -1) THEN C6HALLU = .;
   IF (C7HALLU <= -1) THEN C7HALLU = .;
   IF (C8HALLU <= -1) THEN C8HALLU = .;
   IF (C8AHALLU <= -1) THEN C8AHALLU = .;
   IF (C9HALLU <= -1) THEN C9HALLU = .;
   IF (C2HEROI <= -1) THEN C2HEROI = .;
   IF (C3HEROI <= -1) THEN C3HEROI = .;
   IF (C3AHEROI <= -1) THEN C3AHEROI = .;
   IF (C4HEROI <= -1) THEN C4HEROI = .;
   IF (C5HEROI <= -1) THEN C5HEROI = .;
   IF (C6HEROI <= -1) THEN C6HEROI = .;
   IF (C7HEROI <= -1) THEN C7HEROI = .;
   IF (C8HEROI <= -1) THEN C8HEROI = .;
   IF (C8AHEROI <= -1) THEN C8AHEROI = .;
   IF (C9HEROI <= -1) THEN C9HEROI = .;
   IF (C2MTHDO <= -1) THEN C2MTHDO = .;
   IF (C3MTHDO <= -1) THEN C3MTHDO = .;
   IF (C3AMTHDO <= -1) THEN C3AMTHDO = .;
   IF (C4MTHDO <= -1) THEN C4MTHDO = .;
   IF (C5MTHDO <= -1) THEN C5MTHDO = .;
   IF (C6MTHDO <= -1) THEN C6MTHDO = .;
   IF (C7MTHDO <= -1) THEN C7MTHDO = .;
   IF (C8MTHDO <= -1) THEN C8MTHDO = .;
   IF (C8AMTHDO <= -1) THEN C8AMTHDO = .;
   IF (C9MTHDO <= -1) THEN C9MTHDO = .;
   IF (C2ONARC <= -1) THEN C2ONARC = .;
   IF (C3ONARC <= -1) THEN C3ONARC = .;
   IF (C3AONARC <= -1) THEN C3AONARC = .;
   IF (C4ONARC <= -1) THEN C4ONARC = .;
   IF (C5ONARC <= -1) THEN C5ONARC = .;
   IF (C6ONARC <= -1) THEN C6ONARC = .;
   IF (C7ONARC <= -1) THEN C7ONARC = .;
   IF (C8ONARC <= -1) THEN C8ONARC = .;
   IF (C8AONARC <= -1) THEN C8AONARC = .;
   IF (C9ONARC <= -1) THEN C9ONARC = .;
   IF (C2METHA <= -1) THEN C2METHA = .;
   IF (C3METHA <= -1) THEN C3METHA = .;
   IF (C3AMETHA <= -1) THEN C3AMETHA = .;
   IF (C4METHA <= -1) THEN C4METHA = .;
   IF (C5METHA <= -1) THEN C5METHA = .;
   IF (C6METHA <= -1) THEN C6METHA = .;
   IF (C7METHA <= -1) THEN C7METHA = .;
   IF (C8METHA <= -1) THEN C8METHA = .;
   IF (C8AMETHA <= -1) THEN C8AMETHA = .;
   IF (C9METHA <= -1) THEN C9METHA = .;
   IF (C2DOWNR <= -1) THEN C2DOWNR = .;
   IF (C3DOWNR <= -1) THEN C3DOWNR = .;
   IF (C3ADOWNR <= -1) THEN C3ADOWNR = .;
   IF (C4DOWNR <= -1) THEN C4DOWNR = .;
   IF (C5DOWNR <= -1) THEN C5DOWNR = .;
   IF (C6DOWNR <= -1) THEN C6DOWNR = .;
   IF (C7DOWNR <= -1) THEN C7DOWNR = .;
   IF (C8DOWNR <= -1) THEN C8DOWNR = .;
   IF (C8ADOWNR <= -1) THEN C8ADOWNR = .;
   IF (C9DOWNR <= -1) THEN C9DOWNR = .;
   IF (C2ODRUG <= -1) THEN C2ODRUG = .;
   IF (C3ODRUG <= -1) THEN C3ODRUG = .;
   IF (C3AODRUG <= -1) THEN C3AODRUG = .;
   IF (C4ODRUG <= -1) THEN C4ODRUG = .;
   IF (C5ODRUG <= -1) THEN C5ODRUG = .;
   IF (C6ODRUG <= -1) THEN C6ODRUG = .;
   IF (C7ODRUG <= -1) THEN C7ODRUG = .;
   IF (C8ODRUG <= -1) THEN C8ODRUG = .;
   IF (C8AODRUG <= -1) THEN C8AODRUG = .;
   IF (C9ODRUG <= -1) THEN C9ODRUG = .;
   IF (C10 <= -1) THEN C10 = .;
   IF (C11 <= -1) THEN C11 = .;
   IF (C12_1 <= -1) THEN C12_1 = .;
   IF (C13_1 <= -1.0) THEN C13_1 = .;
   IF (C13_1A <= -1) THEN C13_1A = .;
   IF (C12_2 <= -1) THEN C12_2 = .;
   IF (C13_2 <= -1.0) THEN C13_2 = .;
   IF (C13_2A <= -1) THEN C13_2A = .;
   IF (C12_3 <= -1) THEN C12_3 = .;
   IF (C13_3 <= -1.0) THEN C13_3 = .;
   IF (C13_3A <= -1) THEN C13_3A = .;
   IF (C15INHA <= -1) THEN C15INHA = .;
   IF (C15ALCO <= -1) THEN C15ALCO = .;
   IF (C15MARI <= -1) THEN C15MARI = .;
   IF (C15CRCK <= -1) THEN C15CRCK = .;
   IF (C15COCA <= -1) THEN C15COCA = .;
   IF (C15PCP <= -1) THEN C15PCP = .;
   IF (C15HALU <= -1) THEN C15HALU = .;
   IF (C15HERO <= -1) THEN C15HERO = .;
   IF (C15MTDO <= -1) THEN C15MTDO = .;
   IF (C15ONRC <= -1) THEN C15ONRC = .;
   IF (C15METH <= -1) THEN C15METH = .;
   IF (C15DOWN <= -1) THEN C15DOWN = .;
   IF (C15OTHR <= -1) THEN C15OTHR = .;
   IF (C16INHA <= -1) THEN C16INHA = .;
   IF (C17INHA <= -1) THEN C17INHA = .;
   IF (C18INHA <= -1) THEN C18INHA = .;
   IF (C18AINHA <= -1) THEN C18AINHA = .;
   IF (C19INHA <= -1) THEN C19INHA = .;
   IF (C19AINHA <= -1) THEN C19AINHA = .;
   IF (C20INHA <= -1) THEN C20INHA = .;
   IF (C20AINHA <= -1) THEN C20AINHA = .;
   IF (C21INHA <= -1) THEN C21INHA = .;
   IF (C16ALCO <= -1) THEN C16ALCO = .;
   IF (C17ALCO <= -1) THEN C17ALCO = .;
   IF (C18ALCO <= -1) THEN C18ALCO = .;
   IF (C18AALCO <= -1) THEN C18AALCO = .;
   IF (C19ALCO <= -1) THEN C19ALCO = .;
   IF (C19AALCO <= -1) THEN C19AALCO = .;
   IF (C20ALCO <= -1) THEN C20ALCO = .;
   IF (C20AALCO <= -1) THEN C20AALCO = .;
   IF (C21ALCO <= -1) THEN C21ALCO = .;
   IF (C16MARI <= -1) THEN C16MARI = .;
   IF (C17MARI <= -1) THEN C17MARI = .;
   IF (C18MARI <= -1) THEN C18MARI = .;
   IF (C18AMARI <= -1) THEN C18AMARI = .;
   IF (C19MARI <= -1) THEN C19MARI = .;
   IF (C19AMARI <= -1) THEN C19AMARI = .;
   IF (C20MARI <= -1) THEN C20MARI = .;
   IF (C20AMARI <= -1) THEN C20AMARI = .;
   IF (C21MARI <= -1) THEN C21MARI = .;
   IF (C16CRCK <= -1) THEN C16CRCK = .;
   IF (C17CRCK <= -1) THEN C17CRCK = .;
   IF (C18CRCK <= -1) THEN C18CRCK = .;
   IF (C18ACRCK <= -1) THEN C18ACRCK = .;
   IF (C19CRCK <= -1) THEN C19CRCK = .;
   IF (C19ACRCK <= -1) THEN C19ACRCK = .;
   IF (C20CRCK <= -1) THEN C20CRCK = .;
   IF (C20ACRCK <= -1) THEN C20ACRCK = .;
   IF (C21CRCK <= -1) THEN C21CRCK = .;
   IF (C16COCA <= -1) THEN C16COCA = .;
   IF (C17COCA <= -1) THEN C17COCA = .;
   IF (C18COCA <= -1) THEN C18COCA = .;
   IF (C18ACOCA <= -1) THEN C18ACOCA = .;
   IF (C19COCA <= -1) THEN C19COCA = .;
   IF (C19ACOCA <= -1) THEN C19ACOCA = .;
   IF (C20COCA <= -1) THEN C20COCA = .;
   IF (C20ACOCA <= -1) THEN C20ACOCA = .;
   IF (C21COCA <= -1) THEN C21COCA = .;
   IF (C16PCP <= -1) THEN C16PCP = .;
   IF (C17PCP <= -1) THEN C17PCP = .;
   IF (C18PCP <= -1) THEN C18PCP = .;
   IF (C18APCP <= -1) THEN C18APCP = .;
   IF (C19PCP <= -1) THEN C19PCP = .;
   IF (C19APCP <= -1) THEN C19APCP = .;
   IF (C20PCP <= -1) THEN C20PCP = .;
   IF (C20APCP <= -1) THEN C20APCP = .;
   IF (C21PCP <= -1) THEN C21PCP = .;
   IF (C16HALU <= -1) THEN C16HALU = .;
   IF (C17HALU <= -1) THEN C17HALU = .;
   IF (C18HALU <= -1) THEN C18HALU = .;
   IF (C18AHALU <= -1) THEN C18AHALU = .;
   IF (C19HALU <= -1) THEN C19HALU = .;
   IF (C19AHALU <= -1) THEN C19AHALU = .;
   IF (C20HALU <= -1) THEN C20HALU = .;
   IF (C20AHALU <= -1) THEN C20AHALU = .;
   IF (C21HALU <= -1) THEN C21HALU = .;
   IF (C16HERO <= -1) THEN C16HERO = .;
   IF (C17HERO <= -1) THEN C17HERO = .;
   IF (C18HERO <= -1) THEN C18HERO = .;
   IF (C18AHERO <= -1) THEN C18AHERO = .;
   IF (C19HERO <= -1) THEN C19HERO = .;
   IF (C19AHERO <= -1) THEN C19AHERO = .;
   IF (C20HERO <= -1) THEN C20HERO = .;
   IF (C20AHERO <= -1) THEN C20AHERO = .;
   IF (C21HERO <= -1) THEN C21HERO = .;
   IF (C16MTDO <= -1) THEN C16MTDO = .;
   IF (C17MTDO <= -1) THEN C17MTDO = .;
   IF (C18MTDO <= -1) THEN C18MTDO = .;
   IF (C18AMTDO <= -1) THEN C18AMTDO = .;
   IF (C19MTDO <= -1) THEN C19MTDO = .;
   IF (C19AMTDO <= -1) THEN C19AMTDO = .;
   IF (C20MTDO <= -1) THEN C20MTDO = .;
   IF (C20AMTDO <= -1) THEN C20AMTDO = .;
   IF (C21MTDO <= -1) THEN C21MTDO = .;
   IF (C16ONRC <= -1) THEN C16ONRC = .;
   IF (C17ONRC <= -1) THEN C17ONRC = .;
   IF (C18ONRC <= -1) THEN C18ONRC = .;
   IF (C18AONRC <= -1) THEN C18AONRC = .;
   IF (C19ONRC <= -1) THEN C19ONRC = .;
   IF (C19AONRC <= -1) THEN C19AONRC = .;
   IF (C20ONRC <= -1) THEN C20ONRC = .;
   IF (C20AONRC <= -1) THEN C20AONRC = .;
   IF (C21ONRC <= -1) THEN C21ONRC = .;
   IF (C16METH <= -1) THEN C16METH = .;
   IF (C17METH <= -1) THEN C17METH = .;
   IF (C18METH <= -1) THEN C18METH = .;
   IF (C18AMETH <= -1) THEN C18AMETH = .;
   IF (C19METH <= -1) THEN C19METH = .;
   IF (C19AMETH <= -1) THEN C19AMETH = .;
   IF (C20METH <= -1) THEN C20METH = .;
   IF (C20AMETH <= -1) THEN C20AMETH = .;
   IF (C21METH <= -1) THEN C21METH = .;
   IF (C16DOWN <= -1) THEN C16DOWN = .;
   IF (C17DOWN <= -1) THEN C17DOWN = .;
   IF (C18DOWN <= -1) THEN C18DOWN = .;
   IF (C18ADOWN <= -1) THEN C18ADOWN = .;
   IF (C19DOWN <= -1) THEN C19DOWN = .;
   IF (C19ADOWN <= -1) THEN C19ADOWN = .;
   IF (C20DOWN <= -1) THEN C20DOWN = .;
   IF (C20ADOWN <= -1) THEN C20ADOWN = .;
   IF (C21DOWN <= -1) THEN C21DOWN = .;
   IF (C16OTHR <= -1) THEN C16OTHR = .;
   IF (C17OTHR <= -1) THEN C17OTHR = .;
   IF (C18OTHR <= -1) THEN C18OTHR = .;
   IF (C18AOTHR <= -1) THEN C18AOTHR = .;
   IF (C19OTHR <= -1) THEN C19OTHR = .;
   IF (C19AOTHR <= -1) THEN C19AOTHR = .;
   IF (C20OTHR <= -1) THEN C20OTHR = .;
   IF (C20AOTHR <= -1) THEN C20AOTHR = .;
   IF (C21OTHR <= -1) THEN C21OTHR = .;
   IF (C22 <= -1) THEN C22 = .;
   IF (C23 <= -1) THEN C23 = .;
   IF (C24_1 <= -1) THEN C24_1 = .;
   IF (C25_1 <= -1.0) THEN C25_1 = .;
   IF (C25_1A <= -1) THEN C25_1A = .;
   IF (C24_2 <= -1) THEN C24_2 = .;
   IF (C25_2 <= -1.0) THEN C25_2 = .;
   IF (C25_2A <= -1) THEN C25_2A = .;
   IF (C24_3 <= -1) THEN C24_3 = .;
   IF (C25_3 <= -1.00) THEN C25_3 = .;
   IF (C25_3A <= -1) THEN C25_3A = .;
   IF (C27 <= -1) THEN C27 = .;
   IF (C27A <= -1) THEN C27A = .;
   IF (C27B <= -1) THEN C27B = .;
   IF (C28 <= -1) THEN C28 = .;
   IF (C28A <= -1) THEN C28A = .;
   IF (C28B <= -1) THEN C28B = .;
   IF (C28CA <= -1) THEN C28CA = .;
   IF (C28CB <= -1) THEN C28CB = .;
   IF (C28CC <= -1) THEN C28CC = .;
   IF (C29 <= -1) THEN C29 = .;
   IF (C29A <= -1) THEN C29A = .;
   IF (D1 <= -1) THEN D1 = .;
   IF (D1A <= -1) THEN D1A = .;
   IF (D2 <= -1) THEN D2 = .;
   IF (D3 <= -1) THEN D3 = .;
   IF (D4 <= -1) THEN D4 = .;
   IF (D5 <= -1) THEN D5 = .;
   IF (D6A <= -1) THEN D6A = .;
   IF (D6B <= -1) THEN D6B = .;
   IF (D6C <= -1) THEN D6C = .;
   IF (D6D <= -1) THEN D6D = .;
   IF (D6E <= -1) THEN D6E = .;
   IF (D6F <= -1) THEN D6F = .;
   IF (D6G <= -1) THEN D6G = .;
   IF (D7 <= -1) THEN D7 = .;
   IF (D7AA <= -1) THEN D7AA = .;
   IF (D7BA <= -1) THEN D7BA = .;
   IF (D7AB <= -1) THEN D7AB = .;
   IF (D7BB <= -1) THEN D7BB = .;
   IF (D7AC <= -1) THEN D7AC = .;
   IF (D7BC <= -1) THEN D7BC = .;
   IF (D7AD <= -1) THEN D7AD = .;
   IF (D7BD <= -1) THEN D7BD = .;
   IF (D7AE <= -1) THEN D7AE = .;
   IF (D7BE <= -1) THEN D7BE = .;
   IF (D7AF <= -1) THEN D7AF = .;
   IF (D7BF <= -1) THEN D7BF = .;
   IF (D7AG <= -1) THEN D7AG = .;
   IF (D7BG <= -1) THEN D7BG = .;
   IF (D8 <= -1) THEN D8 = .;
   IF (D9 <= -1) THEN D9 = .;
   IF (D9A_1 <= -1) THEN D9A_1 = .;
   IF (D9A_2 <= -1) THEN D9A_2 = .;
   IF (D9A_3 <= -1) THEN D9A_3 = .;
   IF (D9A_4 <= -1) THEN D9A_4 = .;
   IF (D9A_5 <= -1) THEN D9A_5 = .;
   IF (D9A_6 <= -1) THEN D9A_6 = .;
   IF (D9A_7 <= -1) THEN D9A_7 = .;
   IF (D9A_8 <= -1) THEN D9A_8 = .;
   IF (D9A_9 <= -1) THEN D9A_9 = .;
   IF (D9A_10 <= -1) THEN D9A_10 = .;
   IF (D9A_11 <= -1) THEN D9A_11 = .;
   IF (D9A_12 <= -1) THEN D9A_12 = .;
   IF (D9A_13 <= -1) THEN D9A_13 = .;
   IF (D9A_14 <= -1) THEN D9A_14 = .;
   IF (D9A_15 <= -1) THEN D9A_15 = .;
   IF (D10 <= -1) THEN D10 = .;
   IF (D10A <= -1) THEN D10A = .;
   IF (D11 <= -1) THEN D11 = .;
   IF (D12A <= -1) THEN D12A = .;
   IF (D13A <= -1) THEN D13A = .;
   IF (D13ANUM <= -1) THEN D13ANUM = .;
   IF (D12B <= -1) THEN D12B = .;
   IF (D13B <= -1) THEN D13B = .;
   IF (D13BNUM <= -1) THEN D13BNUM = .;
   IF (D12C <= -1) THEN D12C = .;
   IF (D13C <= -1) THEN D13C = .;
   IF (D13CNUM <= -1) THEN D13CNUM = .;
   IF (D12D <= -1) THEN D12D = .;
   IF (D13D <= -1) THEN D13D = .;
   IF (D13DNUM <= -1) THEN D13DNUM = .;
   IF (D12E <= -1) THEN D12E = .;
   IF (D13E <= -1) THEN D13E = .;
   IF (D13ENUM <= -1) THEN D13ENUM = .;
   IF (D12F <= -1) THEN D12F = .;
   IF (D13F <= -1) THEN D13F = .;
   IF (D13FNUM <= -1) THEN D13FNUM = .;
   IF (D12G <= -1) THEN D12G = .;
   IF (D13G <= -1) THEN D13G = .;
   IF (D13GNUM <= -1) THEN D13GNUM = .;
   IF (D14 <= -1) THEN D14 = .;
   IF (D14A <= -1) THEN D14A = .;
   IF (D15 <= -1) THEN D15 = .;
   IF (D15A <= -1) THEN D15A = .;
   IF (D15B <= -1) THEN D15B = .;
   IF (D16A <= -1) THEN D16A = .;
   IF (D17A <= -1) THEN D17A = .;
   IF (D16B <= -1) THEN D16B = .;
   IF (D17B <= -1) THEN D17B = .;
   IF (D16C <= -1) THEN D16C = .;
   IF (D17C <= -1) THEN D17C = .;
   IF (D16D <= -1) THEN D16D = .;
   IF (D17D <= -1) THEN D17D = .;
   IF (D16E <= -1) THEN D16E = .;
   IF (D17E <= -1) THEN D17E = .;
   IF (D16F <= -1) THEN D16F = .;
   IF (D17F <= -1) THEN D17F = .;
   IF (D16G <= -1) THEN D16G = .;
   IF (D17G <= -1) THEN D17G = .;
   IF (D18 <= -1) THEN D18 = .;
   IF (D19 <= -1) THEN D19 = .;
   IF (D20 <= -1) THEN D20 = .;
   IF (D20A <= -1) THEN D20A = .;
   IF (D20B <= -1) THEN D20B = .;
   IF (D20C <= -1) THEN D20C = .;
   IF (D20D <= -1) THEN D20D = .;
   IF (D20E <= -1) THEN D20E = .;
   IF (D20F <= -1) THEN D20F = .;
   IF (D21 <= -1) THEN D21 = .;
   IF (D21A <= -1) THEN D21A = .;
   IF (D21B <= -1) THEN D21B = .;
   IF (D21C <= -1) THEN D21C = .;
   IF (D21D <= -1) THEN D21D = .;
   IF (D21E <= -1) THEN D21E = .;
   IF (D21F <= -1) THEN D21F = .;
   IF (D22 <= -1) THEN D22 = .;
   IF (D22A <= -1) THEN D22A = .;
   IF (D22B <= -1) THEN D22B = .;
   IF (D22C <= -1) THEN D22C = .;
   IF (D22D <= -1) THEN D22D = .;
   IF (D22E <= -1) THEN D22E = .;
   IF (D22F <= -1) THEN D22F = .;
   IF (D23 <= -1) THEN D23 = .;
   IF (D23A <= -1) THEN D23A = .;
   IF (D23B <= -1) THEN D23B = .;
   IF (D23C <= -1) THEN D23C = .;
   IF (D23D <= -1) THEN D23D = .;
   IF (D23E <= -1) THEN D23E = .;
   IF (D23F <= -1) THEN D23F = .;
   IF (D24 <= -1) THEN D24 = .;
   IF (D24A <= -1) THEN D24A = .;
   IF (D24B <= -1) THEN D24B = .;
   IF (D24C <= -1) THEN D24C = .;
   IF (D24D <= -1) THEN D24D = .;
   IF (D24E <= -1) THEN D24E = .;
   IF (D24F <= -1) THEN D24F = .;
   IF (D25 <= -1) THEN D25 = .;
   IF (D25A <= -1) THEN D25A = .;
   IF (D25B <= -1) THEN D25B = .;
   IF (D25C <= -1) THEN D25C = .;
   IF (D25D <= -1) THEN D25D = .;
   IF (D25E <= -1) THEN D25E = .;
   IF (D25F <= -1) THEN D25F = .;
   IF (D26 <= -1) THEN D26 = .;
   IF (D26A <= -1) THEN D26A = .;
   IF (D26B <= -1) THEN D26B = .;
   IF (D26C <= -1) THEN D26C = .;
   IF (D26D <= -1) THEN D26D = .;
   IF (D26E <= -1) THEN D26E = .;
   IF (D26F <= -1) THEN D26F = .;
   IF (D27 <= -1) THEN D27 = .;
   IF (D27A <= -1) THEN D27A = .;
   IF (D27B <= -1) THEN D27B = .;
   IF (D27C <= -1) THEN D27C = .;
   IF (D27D <= -1) THEN D27D = .;
   IF (D27E <= -1) THEN D27E = .;
   IF (D27F <= -1) THEN D27F = .;
   IF (D28 <= -1) THEN D28 = .;
   IF (D28A <= -1) THEN D28A = .;
   IF (D28B <= -1) THEN D28B = .;
   IF (D28C <= -1) THEN D28C = .;
   IF (D28D <= -1) THEN D28D = .;
   IF (D28E <= -1) THEN D28E = .;
   IF (D28F <= -1) THEN D28F = .;
   IF (D29 <= -1) THEN D29 = .;
   IF (D29A <= -1) THEN D29A = .;
   IF (D29B <= -1) THEN D29B = .;
   IF (D29C <= -1) THEN D29C = .;
   IF (D29D <= -1) THEN D29D = .;
   IF (D29E <= -1) THEN D29E = .;
   IF (D29F <= -1) THEN D29F = .;
   IF (D30 <= -1) THEN D30 = .;
   IF (D30A <= -1) THEN D30A = .;
   IF (D30B <= -1) THEN D30B = .;
   IF (D30C <= -1) THEN D30C = .;
   IF (D30D <= -1) THEN D30D = .;
   IF (D30E <= -1) THEN D30E = .;
   IF (D30F <= -1) THEN D30F = .;
   IF (D31 <= -1) THEN D31 = .;
   IF (D31A <= -1) THEN D31A = .;
   IF (D31B <= -1) THEN D31B = .;
   IF (D31C <= -1) THEN D31C = .;
   IF (D31D <= -1) THEN D31D = .;
   IF (D31E <= -1) THEN D31E = .;
   IF (D31F <= -1) THEN D31F = .;
   IF (D32 <= -1) THEN D32 = .;
   IF (D32A <= -1) THEN D32A = .;
   IF (D32B <= -1) THEN D32B = .;
   IF (D32C <= -1) THEN D32C = .;
   IF (D32D <= -1) THEN D32D = .;
   IF (D32E <= -1) THEN D32E = .;
   IF (D32F <= -1) THEN D32F = .;
   IF (D33 <= -1) THEN D33 = .;
   IF (D33A <= -1) THEN D33A = .;
   IF (D33B <= -1) THEN D33B = .;
   IF (D33C <= -1) THEN D33C = .;
   IF (D33D <= -1) THEN D33D = .;
   IF (D33E <= -1) THEN D33E = .;
   IF (D33F <= -1) THEN D33F = .;
   IF (D34 <= -1) THEN D34 = .;
   IF (D34A <= -1) THEN D34A = .;
   IF (D34B <= -1) THEN D34B = .;
   IF (D34C <= -1) THEN D34C = .;
   IF (D34D <= -1) THEN D34D = .;
   IF (D34E <= -1) THEN D34E = .;
   IF (D34F <= -1) THEN D34F = .;
   IF (D35 <= -1) THEN D35 = .;
   IF (D35A <= -1) THEN D35A = .;
   IF (D35B <= -1) THEN D35B = .;
   IF (D35C <= -1) THEN D35C = .;
   IF (D35D <= -1) THEN D35D = .;
   IF (D35E <= -1) THEN D35E = .;
   IF (D35F <= -1) THEN D35F = .;
   IF (D36 <= -1) THEN D36 = .;
   IF (D36AA <= -1) THEN D36AA = .;
   IF (D36AB <= -1) THEN D36AB = .;
   IF (D36AC <= -1) THEN D36AC = .;
   IF (D35AD <= -1) THEN D35AD = .;
   IF (E1 <= -1) THEN E1 = .;
   IF (E1A <= -1) THEN E1A = .;
   IF (E2 <= -1) THEN E2 = .;
   IF (E3 <= -1) THEN E3 = .;
   IF (E4MONTH <= -1) THEN E4MONTH = .;
   IF (E4YEAR <= -1) THEN E4YEAR = .;
   IF (E5 <= -1) THEN E5 = .;
   IF (E6 <= -1) THEN E6 = .;
   IF (E7 <= -1) THEN E7 = .;
   IF (E8A <= -1) THEN E8A = .;
   IF (E8B <= -1) THEN E8B = .;
   IF (E9 <= -1) THEN E9 = .;
   IF (E10 <= -1) THEN E10 = .;
   IF (F1 <= -1) THEN F1 = .;
   IF (F2 <= -1) THEN F2 = .;
   IF (F3 <= -1) THEN F3 = .;
   IF (F3A <= -1) THEN F3A = .;
   IF (F3B <= -1) THEN F3B = .;
   IF (F4 <= -1) THEN F4 = .;
   IF (F5 <= -1) THEN F5 = .;
   IF (F5A <= -1) THEN F5A = .;
   IF (F6 <= -1) THEN F6 = .;
   IF (F6A <= -1) THEN F6A = .;
   IF (F7 <= -1) THEN F7 = .;
   IF (F8 <= -1) THEN F8 = .;
   IF (F8A <= -1) THEN F8A = .;
   IF (F9 <= -1) THEN F9 = .;
   IF (F10 <= -1) THEN F10 = .;
   IF (F10A <= -1) THEN F10A = .;
   IF (F11 <= -1) THEN F11 = .;
   IF (F11A <= -1) THEN F11A = .;
   IF (F12 <= -1) THEN F12 = .;
   IF (F12A <= -1) THEN F12A = .;
   IF (F13 <= -1) THEN F13 = .;
   IF (F13A <= -1) THEN F13A = .;
   IF (F13B <= -1) THEN F13B = .;
   IF (F13C <= -1) THEN F13C = .;
   IF (F13D <= -1) THEN F13D = .;
   IF (F13E <= -1) THEN F13E = .;
   IF (F13F <= -1) THEN F13F = .;
   IF (F14 <= -1) THEN F14 = .;
   IF (F14A <= -1) THEN F14A = .;
   IF (F15 <= -1) THEN F15 = .;
   IF (F15A <= -1) THEN F15A = .;
   IF (F15B <= -1) THEN F15B = .;
   IF (F15C <= -1) THEN F15C = .;
   IF (F16 <= -1) THEN F16 = .;
   IF (F16A <= -1) THEN F16A = .;
   IF (F17 <= -1) THEN F17 = .;
   IF (F17A <= -1) THEN F17A = .;
   IF (F17B <= -1) THEN F17B = .;
   IF (F17C <= -1) THEN F17C = .;
   IF (F19 <= -1) THEN F19 = .;
   IF (F19A_1 <= -1) THEN F19A_1 = .;
   IF (F19A_2 <= -1) THEN F19A_2 = .;
   IF (F19A_3 <= -1) THEN F19A_3 = .;
   IF (F19A_4 <= -1) THEN F19A_4 = .;
   IF (F19A_5 <= -1) THEN F19A_5 = .;
   IF (F19A_6 <= -1) THEN F19A_6 = .;
   IF (F19A_7 <= -1) THEN F19A_7 = .;
   IF (F19A_8 <= -1) THEN F19A_8 = .;
   IF (F19A_9 <= -1) THEN F19A_9 = .;
   IF (F19A_10 <= -1) THEN F19A_10 = .;
   IF (F19B_0 <= -1) THEN F19B_0 = .;
   IF (F19B_1 <= -1) THEN F19B_1 = .;
   IF (F19B_2 <= -1) THEN F19B_2 = .;
   IF (F19B_3 <= -1) THEN F19B_3 = .;
   IF (F19B_4 <= -1) THEN F19B_4 = .;
   IF (F19B_5 <= -1) THEN F19B_5 = .;
   IF (F19B_6 <= -1) THEN F19B_6 = .;
   IF (F19B_7 <= -1) THEN F19B_7 = .;
   IF (F19B_8 <= -1) THEN F19B_8 = .;
   IF (F19B_9 <= -1) THEN F19B_9 = .;
   IF (F19B_10 <= -1) THEN F19B_10 = .;
   IF (F19B_11 <= -1) THEN F19B_11 = .;
   IF (F19B_12 <= -1) THEN F19B_12 = .;
   IF (F19B_13 <= -1) THEN F19B_13 = .;
   IF (F19B_14 <= -1) THEN F19B_14 = .;
   IF (F19B_15 <= -1) THEN F19B_15 = .;
   IF (F19B_16 <= -1) THEN F19B_16 = .;
   IF (F19B_17 <= -1) THEN F19B_17 = .;
   IF (F19C <= -1) THEN F19C = .;
   IF (G1 <= -1) THEN G1 = .;
   IF (G2 <= -1) THEN G2 = .;
   IF (G3 <= -1) THEN G3 = .;
   IF (G3A <= -1) THEN G3A = .;
   IF (G3B <= -1) THEN G3B = .;
   IF (G4 <= -1) THEN G4 = .;
   IF (G5 <= -1) THEN G5 = .;
   IF (G6 <= -1) THEN G6 = .;
   IF (G7 <= -1) THEN G7 = .;
   IF (G8 <= -1) THEN G8 = .;
   IF (G9 <= -1) THEN G9 = .;
   IF (G10 <= -1) THEN G10 = .;
   IF (G11 <= -1) THEN G11 = .;
   IF (G12 <= -1) THEN G12 = .;
   IF (G13 <= -1) THEN G13 = .;
   IF (G14 <= -1) THEN G14 = .;
   IF (G15 <= -1) THEN G15 = .;
   IF (G16 <= -1) THEN G16 = .;
   IF (G17 <= -1) THEN G17 = .;
   IF (G18 <= -1) THEN G18 = .;
   IF (G19 <= -1) THEN G19 = .;
   IF (G20 <= -1) THEN G20 = .;
   IF (G20A <= -1) THEN G20A = .;
   IF (G20B <= -1) THEN G20B = .;
   IF (G21 <= -1) THEN G21 = .;
   IF (G22 <= -1) THEN G22 = .;
   IF (G23 <= -1) THEN G23 = .;
   IF (G24 <= -1) THEN G24 = .;
   IF (G25 <= -1) THEN G25 = .;
   IF (G26 <= -1) THEN G26 = .;
   IF (G27 <= -1) THEN G27 = .;
   IF (G28 <= -1) THEN G28 = .;
   IF (G28A <= -1) THEN G28A = .;
   IF (G28B <= -1) THEN G28B = .;
   IF (G29 <= -1) THEN G29 = .;
   IF (G30 <= -1) THEN G30 = .;
   IF (G31 <= -1) THEN G31 = .;
   IF (G32 <= -1) THEN G32 = .;
   IF (G33 <= -1) THEN G33 = .;
   IF (G34 <= -1) THEN G34 = .;
   IF (G35 <= -1) THEN G35 = .;
   IF (G36 <= -1) THEN G36 = .;
   IF (G37 <= -1) THEN G37 = .;
   IF (G38 <= -1) THEN G38 = .;
   IF (G39 <= -1) THEN G39 = .;
   IF (G40 <= -1) THEN G40 = .;
   IF (G41 <= -1) THEN G41 = .;
   IF (G42 <= -1) THEN G42 = .;
   IF (G43 <= -1) THEN G43 = .;
   IF (G44 <= -1) THEN G44 = .;
   IF (G45 <= -1) THEN G45 = .;
   IF (G46 <= -1) THEN G46 = .;
   IF (G47 <= -1) THEN G47 = .;
   IF (G48 <= -1) THEN G48 = .;
   IF (G49 <= -1) THEN G49 = .;
   IF (G50 <= -1) THEN G50 = .;
   IF (G51A <= -1) THEN G51A = .;
   IF (G51B <= -1) THEN G51B = .;
   IF (G51C <= -1) THEN G51C = .;
   IF (G51D <= -1) THEN G51D = .;
   IF (G51E <= -1) THEN G51E = .;
   IF (G51F <= -1) THEN G51F = .;
   IF (G51G <= -1) THEN G51G = .;
   IF (G51H <= -1) THEN G51H = .;
   IF (G51I <= -1) THEN G51I = .;
   IF (G51J <= -1) THEN G51J = .;
   IF (G51K <= -1) THEN G51K = .;
   IF (G51AA <= -1) THEN G51AA = .;
   IF (G51BA <= -1) THEN G51BA = .;
   IF (G51AB <= -1) THEN G51AB = .;
   IF (G51BB <= -1) THEN G51BB = .;
   IF (G51AC <= -1) THEN G51AC = .;
   IF (G51BC <= -1) THEN G51BC = .;
   IF (G51AD <= -1) THEN G51AD = .;
   IF (G51BD <= -1) THEN G51BD = .;
   IF (G51AE <= -1) THEN G51AE = .;
   IF (G51BE <= -1) THEN G51BE = .;
   IF (G51AF <= -1) THEN G51AF = .;
   IF (G51BF <= -1) THEN G51BF = .;
   IF (G51AG <= -1) THEN G51AG = .;
   IF (G51BG <= -1) THEN G51BG = .;
   IF (G51AH <= -1) THEN G51AH = .;
   IF (G51BH <= -1) THEN G51BH = .;
   IF (G51AI <= -1) THEN G51AI = .;
   IF (G51BI <= -1) THEN G51BI = .;
   IF (G51AJ <= -1) THEN G51AJ = .;
   IF (G51BJ <= -1) THEN G51BJ = .;
   IF (G51AK <= -1) THEN G51AK = .;
   IF (G51BK <= -1) THEN G51BK = .;
   IF (G52 <= -1) THEN G52 = .;
   IF (G53 <= -1) THEN G53 = .;
   IF (G54 <= -1) THEN G54 = .;
   IF (G55 <= -1) THEN G55 = .;
   IF (G56 <= -1) THEN G56 = .;
   IF (G57 <= -1) THEN G57 = .;
   IF (G58 <= -1) THEN G58 = .;
   IF (G59 <= -1) THEN G59 = .;
   IF (G60 <= -1) THEN G60 = .;
   IF (G61 <= -1) THEN G61 = .;
   IF (G62 <= -1) THEN G62 = .;
   IF (G63 <= -1) THEN G63 = .;
   IF (G64 <= -1) THEN G64 = .;
   IF (G65 <= -1) THEN G65 = .;
   IF (G66 <= -1) THEN G66 = .;
   IF (G67 <= -1) THEN G67 = .;
   IF (G68 <= -1) THEN G68 = .;
   IF (G69 <= -1) THEN G69 = .;
   IF (G70 <= -1) THEN G70 = .;
   IF (G71 <= -1) THEN G71 = .;
   IF (G72 <= -1) THEN G72 = .;
   IF (G73 <= -1) THEN G73 = .;
   IF (G74 <= -1) THEN G74 = .;
   IF (G75 <= -1) THEN G75 = .;
   IF (G76 <= -1) THEN G76 = .;
   IF (G77 <= -1) THEN G77 = .;
   IF (G78 <= -1) THEN G78 = .;
   IF (G79 <= -1) THEN G79 = .;
   IF (G80 <= -1) THEN G80 = .;
   IF (G81 <= -1) THEN G81 = .;
   IF (G82 <= -1) THEN G82 = .;
   IF (G83 <= -1) THEN G83 = .;
   IF (G84 <= -1) THEN G84 = .;
   IF (G86 <= -1) THEN G86 = .;
   IF (G87 <= -1) THEN G87 = .;
   IF (G88 <= -1) THEN G88 = .;
   IF (G89 <= -1) THEN G89 = .;
   IF (G90 <= -1) THEN G90 = .;
   IF (G91 <= -1) THEN G91 = .;
   IF (G92 <= -1) THEN G92 = .;
   IF (G93 <= -1) THEN G93 = .;
   IF (G95 <= -1) THEN G95 = .;
   IF (G96 <= -1) THEN G96 = .;
   IF (G97 <= -1) THEN G97 = .;
   IF (G98 <= -1) THEN G98 = .;
   IF (G99 <= -1) THEN G99 = .;
   IF (H1 <= -1) THEN H1 = .;
   IF (H2 <= -1) THEN H2 = .;
   IF (H3 <= -1) THEN H3 = .;
   IF (H3BDOL <= -1.00) THEN H3BDOL = .;
   IF (H3BRATE <= -1) THEN H3BRATE = .;
   IF (H4 <= -1) THEN H4 = .;
   IF (H4ADOL <= -1.00) THEN H4ADOL = .;
   IF (H4ARATE <= -1) THEN H4ARATE = .;
   IF (SAME1ST <= -1) THEN SAME1ST = .;
   IF (H6 <= -1) THEN H6 = .;
   IF (H7 <= -1) THEN H7 = .;
   IF (SAME2ND <= -1) THEN SAME2ND = .;
   IF (H7BDOL <= -1.00) THEN H7BDOL = .;
   IF (H7ARATE <= -1) THEN H7ARATE = .;
   IF (H8 <= -1) THEN H8 = .;
   IF (H8ADOL <= -1.00) THEN H8ADOL = .;
   IF (H8ARATE <= -1) THEN H8ARATE = .;
   IF (SAME3RD <= -1) THEN SAME3RD = .;
   IF (H10 <= -1) THEN H10 = .;
   IF (H10A <= -1) THEN H10A = .;
   IF (H10BDOL <= -1.00) THEN H10BDOL = .;
   IF (H10BRTE <= -1) THEN H10BRTE = .;
   IF (SAME4TH <= -1) THEN SAME4TH = .;
   IF (H11 <= -1) THEN H11 = .;
   IF (H12 <= -1) THEN H12 = .;
   IF (H13 <= -1) THEN H13 = .;
   IF (SAME5TH <= -1) THEN SAME5TH = .;
   IF (H13BDOL <= -1.00) THEN H13BDOL = .;
   IF (H13BRTE <= -1) THEN H13BRTE = .;
   IF (H14 <= -1) THEN H14 = .;
   IF (H14ADOL <= -1.00) THEN H14ADOL = .;
   IF (H14ARTE <= -1) THEN H14ARTE = .;
   IF (SAME6TH <= -1) THEN SAME6TH = .;
   IF (H15 <= -1) THEN H15 = .;
   IF (SAME7TH <= -1) THEN SAME7TH = .;
   IF (H15B <= -1) THEN H15B = .;
   IF (H15CDOL <= -1.00) THEN H15CDOL = .;
   IF (H15CRTE <= -1) THEN H15CRTE = .;
   IF (H17 <= -1) THEN H17 = .;
   IF (H17A <= -1) THEN H17A = .;
   IF (H17BDOL <= -1.00) THEN H17BDOL = .;
   IF (H17BRTE <= -1) THEN H17BRTE = .;
   IF (SAME8TH <= -1) THEN SAME8TH = .;
   IF (H19 <= -1) THEN H19 = .;
   IF (H19A_1 <= -1) THEN H19A_1 = .;
   IF (H19A_2 <= -1) THEN H19A_2 = .;
   IF (H19A_3 <= -1) THEN H19A_3 = .;
   IF (H19A_4 <= -1) THEN H19A_4 = .;
   IF (H19A_5 <= -1) THEN H19A_5 = .;
   IF (H19A_6 <= -1) THEN H19A_6 = .;
   IF (H19A_7 <= -1) THEN H19A_7 = .;
   IF (H19A_8 <= -1) THEN H19A_8 = .;
   IF (H19B <= -1) THEN H19B = .;
   IF (H21A <= -1) THEN H21A = .;
   IF (H22A <= -1.00) THEN H22A = .;
   IF (H22ATIM <= -1) THEN H22ATIM = .;
   IF (H21B <= -1) THEN H21B = .;
   IF (H22B <= -1.00) THEN H22B = .;
   IF (H22BTIM <= -1) THEN H22BTIM = .;
   IF (H21C <= -1) THEN H21C = .;
   IF (H22C <= -1.00) THEN H22C = .;
   IF (H22CTIM <= -1) THEN H22CTIM = .;
   IF (H21D <= -1) THEN H21D = .;
   IF (H22D <= -1.00) THEN H22D = .;
   IF (H22DTIM <= -1) THEN H22DTIM = .;
   IF (H21E <= -1) THEN H21E = .;
   IF (H22E <= -1) THEN H22E = .;
   IF (H22ETIM <= -1) THEN H22ETIM = .;
   IF (H21F <= -1) THEN H21F = .;
   IF (H22F <= -1.00) THEN H22F = .;
   IF (H22FTIM <= -1) THEN H22FTIM = .;
   IF (H21G <= -1) THEN H21G = .;
   IF (H22G <= -1) THEN H22G = .;
   IF (H22GTIM <= -1) THEN H22GTIM = .;
   IF (H21H <= -1) THEN H21H = .;
   IF (H22H <= -1.00) THEN H22H = .;
   IF (H22HTIM <= -1) THEN H22HTIM = .;
   IF (PHONE1 <= -1) THEN PHONE1 = .;
   IF (PHONE2 <= -1) THEN PHONE2 = .;
   IF (PERSON2 <= -1) THEN PERSON2 = .;
   IF (PHONE3 <= -1) THEN PHONE3 = .;
   IF (ENDYEAR <= -1) THEN ENDYEAR = .;
   IF (TOTTIME <= -1) THEN TOTTIME = .;
   IF (BOXII <= -1) THEN BOXII = .;
   IF (BOXIII <= -1) THEN BOXIII = .;
   IF (BOXIV <= -1) THEN BOXIV = .;
   IF (BOXRECPT <= -1) THEN BOXRECPT = .;
   IF (I11A <= -1) THEN I11A = .;
   IF (I11AA <= -1) THEN I11AA = .;
   IF (I11AB <= -1) THEN I11AB = .;
   IF (I11B <= -1) THEN I11B = .;
   IF (I11BA <= -1) THEN I11BA = .;
   IF (I11BB <= -1) THEN I11BB = .;
   IF (I11C <= -1) THEN I11C = .;
   IF (I11CA <= -1) THEN I11CA = .;
   IF (I11CB <= -1) THEN I11CB = .;
   IF (I11D <= -1) THEN I11D = .;
   IF (I11DA <= -1) THEN I11DA = .;
   IF (I11DB <= -1) THEN I11DB = .;
   IF (I11E <= -1) THEN I11E = .;
   IF (I11EA <= -1) THEN I11EA = .;
   IF (I11EB <= -1) THEN I11EB = .;
   IF (I11F <= -1) THEN I11F = .;
   IF (I11FA <= -1) THEN I11FA = .;
   IF (I11FB <= -1) THEN I11FB = .;
   IF (I11G <= -1) THEN I11G = .;
   IF (I11GA <= -1) THEN I11GA = .;
   IF (I11GB <= -1) THEN I11GB = .;
   IF (I11AC <= -1) THEN I11AC = .;
   IF (I11BC <= -1) THEN I11BC = .;
   IF (I11CC <= -1) THEN I11CC = .;
   IF (I11DC <= -1) THEN I11DC = .;
   IF (I11EC <= -1) THEN I11EC = .;
   IF (I11FC <= -1) THEN I11FC = .;
   IF (I11GC <= -1) THEN I11GC = .;
   IF (D6A_1 <= -1) THEN D6A_1 = .;
   IF (INHAL <= -1) THEN INHAL = .;
   IF (ALCOHOL <= -1) THEN ALCOHOL = .;
   IF (MARIJUAN <= -1) THEN MARIJUAN = .;
   IF (CRACK <= -1) THEN CRACK = .;
   IF (COCAINE <= -1) THEN COCAINE = .;
   IF (PCP <= -1) THEN PCP = .;
   IF (HALLUCIN <= -1) THEN HALLUCIN = .;
   IF (HEROIN <= -1) THEN HEROIN = .;
   IF (ILLMETH <= -1) THEN ILLMETH = .;
   IF (NARC <= -1) THEN NARC = .;
   IF (METHAMPH <= -1) THEN METHAMPH = .;
   IF (DOWNERS <= -1) THEN DOWNERS = .;
   IF (OTHDRUG <= -1) THEN OTHDRUG = .;
   IF (AGEFINH <= -1) THEN AGEFINH = .;
   IF (AGEFALC <= -1) THEN AGEFALC = .;
   IF (AGEFMAR <= -1) THEN AGEFMAR = .;
   IF (AGFCRK <= -1) THEN AGFCRK = .;
   IF (AGEFCOC <= -1) THEN AGEFCOC = .;
   IF (AGEFPCP <= -1) THEN AGEFPCP = .;
   IF (AGEFHAL <= -1) THEN AGEFHAL = .;
   IF (AGEFHER <= -1) THEN AGEFHER = .;
   IF (AGEFMTH <= -1) THEN AGEFMTH = .;
   IF (AGEFNAR <= -1) THEN AGEFNAR = .;
   IF (AGEFAMP <= -1) THEN AGEFAMP = .;
   IF (AGEFDWN <= -1) THEN AGEFDWN = .;
   IF (AGEFOTH <= -1) THEN AGEFOTH = .;
   IF (USBINH <= -1) THEN USBINH = .;
   IF (USBALC <= -1) THEN USBALC = .;
   IF (USBMAR <= -1) THEN USBMAR = .;
   IF (USBCRK <= -1) THEN USBCRK = .;
   IF (USBCOC <= -1) THEN USBCOC = .;
   IF (USBPCP <= -1) THEN USBPCP = .;
   IF (USBHAL <= -1) THEN USBHAL = .;
   IF (USBHER <= -1) THEN USBHER = .;
   IF (USBMTH <= -1) THEN USBMTH = .;
   IF (USBNAR <= -1) THEN USBNAR = .;
   IF (USBAMP <= -1) THEN USBAMP = .;
   IF (USBDWN <= -1) THEN USBDWN = .;
   IF (USBOTH <= -1) THEN USBOTH = .;
   IF (USBDINH <= -1) THEN USBDINH = .;
   IF (USBDALC <= -1) THEN USBDALC = .;
   IF (USBDMAR <= -1) THEN USBDMAR = .;
   IF (USBDCRK <= -1) THEN USBDCRK = .;
   IF (USBDCOC <= -1) THEN USBDCOC = .;
   IF (USBDPCP <= -1) THEN USBDPCP = .;
   IF (USBDHAL <= -1) THEN USBDHAL = .;
   IF (USBDHER <= -1) THEN USBDHER = .;
   IF (USBDMTH <= -1) THEN USBDMTH = .;
   IF (USBDNAR <= -1) THEN USBDNAR = .;
   IF (USBDAMP <= -1) THEN USBDAMP = .;
   IF (USBDDWN <= -1) THEN USBDDWN = .;
   IF (USBDOTH <= -1) THEN USBDOTH = .;
   IF (USAINH <= -1) THEN USAINH = .;
   IF (USAALC <= -1) THEN USAALC = .;
   IF (USAMAR <= -1) THEN USAMAR = .;
   IF (USACRK <= -1) THEN USACRK = .;
   IF (USACOC <= -1) THEN USACOC = .;
   IF (USAPCP <= -1) THEN USAPCP = .;
   IF (USAHAL <= -1) THEN USAHAL = .;
   IF (USAHER <= -1) THEN USAHER = .;
   IF (USAMTH <= -1) THEN USAMTH = .;
   IF (USANAR <= -1) THEN USANAR = .;
   IF (USAAMP <= -1) THEN USAAMP = .;
   IF (USADWN <= -1) THEN USADWN = .;
   IF (USAOTH <= -1) THEN USAOTH = .;
   IF (USADINH <= -1) THEN USADINH = .;
   IF (USADALC <= -1) THEN USADALC = .;
   IF (USADMAR <= -1) THEN USADMAR = .;
   IF (USADCRK <= -1) THEN USADCRK = .;
   IF (USADCOC <= -1) THEN USADCOC = .;
   IF (USADPCP <= -1) THEN USADPCP = .;
   IF (USADHAL <= -1) THEN USADHAL = .;
   IF (USADHER <= -1) THEN USADHER = .;
   IF (USADMTH <= -1) THEN USADMTH = .;
   IF (USADNAR <= -1) THEN USADNAR = .;
   IF (USADAMP <= -1) THEN USADAMP = .;
   IF (USADDWN <= -1) THEN USADDWN = .;
   IF (USADOTH <= -1) THEN USADOTH = .;
   IF (USYINH <= -1) THEN USYINH = .;
   IF (USYALC <= -1) THEN USYALC = .;
   IF (USYMAR <= -1) THEN USYMAR = .;
   IF (USYCRK <= -1) THEN USYCRK = .;
   IF (USYCOC <= -1) THEN USYCOC = .;
   IF (USYPCP <= -1) THEN USYPCP = .;
   IF (USYHAL <= -1) THEN USYHAL = .;
   IF (USYHER <= -1) THEN USYHER = .;
   IF (USYMTH <= -1) THEN USYMTH = .;
   IF (USYNAR <= -1) THEN USYNAR = .;
   IF (USYAMP <= -1) THEN USYAMP = .;
   IF (USYDWN <= -1) THEN USYDWN = .;
   IF (USYOTH <= -1) THEN USYOTH = .;
   IF (USYDINH <= -1) THEN USYDINH = .;
   IF (USYDALC <= -1) THEN USYDALC = .;
   IF (USYDMAR <= -1) THEN USYDMAR = .;
   IF (USYDCRK <= -1) THEN USYDCRK = .;
   IF (USYDCOC <= -1) THEN USYDCOC = .;
   IF (USYDPCP <= -1) THEN USYDPCP = .;
   IF (USYDHAL <= -1) THEN USYDHAL = .;
   IF (USYDHER <= -1) THEN USYDHER = .;
   IF (USYDMTH <= -1) THEN USYDMTH = .;
   IF (USYDNAR <= -1) THEN USYDNAR = .;
   IF (USYDAMP <= -1) THEN USYDAMP = .;
   IF (USYDDWN <= -1) THEN USYDDWN = .;
   IF (USYDOTH <= -1) THEN USYDOTH = .;
   IF (USNINH <= -1) THEN USNINH = .;
   IF (USNALC <= -1) THEN USNALC = .;
   IF (USNMAR <= -1) THEN USNMAR = .;
   IF (USNCRK <= -1) THEN USNCRK = .;
   IF (USNCOC <= -1) THEN USNCOC = .;
   IF (USNPCP <= -1) THEN USNPCP = .;
   IF (USNHAL <= -1) THEN USNHAL = .;
   IF (USNHER <= -1) THEN USNHER = .;
   IF (USNMTH <= -1) THEN USNMTH = .;
   IF (USNNAR <= -1) THEN USNNAR = .;
   IF (USNAMP <= -1) THEN USNAMP = .;
   IF (USNDWN <= -1) THEN USNDWN = .;
   IF (USNOTH <= -1) THEN USNOTH = .;
   IF (USNMINH <= -1) THEN USNMINH = .;
   IF (USNMALC <= -1) THEN USNMALC = .;
   IF (USNMMAR <= -1) THEN USNMMAR = .;
   IF (USNMCRK <= -1) THEN USNMCRK = .;
   IF (USNMCOC <= -1) THEN USNMCOC = .;
   IF (USNMPCP <= -1) THEN USNMPCP = .;
   IF (USNMHAL <= -1) THEN USNMHAL = .;
   IF (USNMHER <= -1) THEN USNMHER = .;
   IF (USNMMTH <= -1) THEN USNMMTH = .;
   IF (USNMNAR <= -1) THEN USNMNAR = .;
   IF (USNMAMP <= -1) THEN USNMAMP = .;
   IF (USNMDWN <= -1) THEN USNMDWN = .;
   IF (USNMOTH <= -1) THEN USNMOTH = .;
   IF (USMINH <= -1) THEN USMINH = .;
   IF (USMALC <= -1) THEN USMALC = .;
   IF (USMMAR <= -1) THEN USMMAR = .;
   IF (USMCRK <= -1) THEN USMCRK = .;
   IF (USMCOC <= -1) THEN USMCOC = .;
   IF (USMPCP <= -1) THEN USMPCP = .;
   IF (USMHAL <= -1) THEN USMHAL = .;
   IF (USMHER <= -1) THEN USMHER = .;
   IF (USMMTH <= -1) THEN USMMTH = .;
   IF (USMNAR <= -1) THEN USMNAR = .;
   IF (USMAMP <= -1) THEN USMAMP = .;
   IF (USMDWN <= -1) THEN USMDWN = .;
   IF (USMOTH <= -1) THEN USMOTH = .;
   IF (USBSEC <= -1) THEN USBSEC = .;
   IF (USASEC <= -1) THEN USASEC = .;
   IF (USBANY <= -1) THEN USBANY = .;
   IF (USAANY <= -1) THEN USAANY = .;
   IF (TRTYPE <= -1) THEN TRTYPE = .;
   IF (LOS <= -1) THEN LOS = .;
   IF (LOSCAT <= -1) THEN LOSCAT = .;
   IF (RACE <= -1) THEN RACE = .;
   IF (DISAGE <= -1) THEN DISAGE = .;
   IF (DISAGE2 <= -1) THEN DISAGE2 = .;
   IF (PRETRT <= -1) THEN PRETRT = .;
   IF (COMPTRT <= -1) THEN COMPTRT = .;
   IF (AFTTRT <= -1) THEN AFTTRT = .;
   IF (HELPTRT <= -1) THEN HELPTRT = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT MODE mode. A1 a1ffffff. A3 a3ffffff.
         A4 a4ffffff. A4A_1 a4a_1fff. A4A_2 a4a_2fff.
         A4A_3 a4a_3fff. A4A_4 a4a_4fff. A5 a5ffffff.
         A6 a6ffffff. A7 a7ffffff. A8 a8ffffff.
         A8A_1 a8a_1fff. A8A_2 a8a_2fff. A8A_3 a8a_3fff.
         A8A_4 a8a_4fff. A9 a9ffffff. A9A a9a.
         A10 a10fffff. A11 a11fffff. B1 b1ffffff.
         B2 b2ffffff. B2B b2b. B4 b4ffffff.
         B5 b5ffffff. B5A b5a. B6_1 b6_1ffff.
         B6_2 b6_2ffff. B6_3 b6_3ffff. B6_4 b6_4ffff.
         B6_5 b6_5ffff. B6_6 b6_6ffff. B6_7 b6_7ffff.
         B6_8 b6_8ffff. B6_9 b6_9ffff. B6_10 b6_10fff.
         B6_11 b6_11fff. B6_12 b6_12fff. B6_13 b6_13fff.
         B6_14 b6_14fff. B7_1 b7_1ffff. B7_2 b7_2ffff.
         B7_3 b7_3ffff. B7_4 b7_4ffff. B7_5 b7_5ffff.
         B8A b8a. B8B b8b. B8C b8c.
         B8D b8d. B8E b8e. B8F b8f.
         B8G b8g. B9A b9a. B9B b9b.
         B9C b9c. B9D b9d. B9E b9e.
         B9F b9f. B10 b10fffff. B11 b11fffff.
         B11A b11a. B12 b12fffff. B12A_1 b12a_1ff.
         B12A_2 b12a_2ff. B12A_3 b12a_3ff. B12A_4 b12a_4ff.
         B12A_5 b12a_5ff. B12A_6 b12a_6ff. B12A_7 b12a_7ff.
         B12A_8 b12a_8ff. B12A_9 b12a_9ff. B12A_10 b12a_10f.
         B12A_11 b12a_11f. B12A_12 b12a_12f. B12A_13 b12a_13f.
         B12B b12b. B12C b12c. B13 b13fffff.
         B14 b14fffff. B15 b15fffff. B16 b16fffff.
         B16A b16a. B16B b16b. B17 b17fffff.
         B18 b18fffff. B18AA b18aa. B18AB b18ab.
         B18AC b18ac. B19A b19a. B19B b19b.
         B19C b19c. B19D b19d. B19E b19e.
         B19F b19f. B19G b19g. B19H b19h.
         B19I b19i. B20 b20fffff. BOX20A box20a.
         B21CODE b21code. B21BYR b21byr. B21C b21c.
         B21D b21d. B21D2 b21d2fff. B21ECOD b21ecod.
         B21GY b21gy. B21H b21h. B22 b22fffff.
         B23A b23a. B23B b23b. B23C b23c.
         B23D b23d. B23E b23e. B24A b24a.
         B24B b24b. B24C b24c. B25 b25fffff.
         B25AA b25aa. B25AB b25ab. B25AC b25ac.
         B26 b26fffff. B26A b26a. B27CODE b27code.
         B29A b29a. B29B b29b. B29C_1 b29c_1ff.
         B29C_2 b29c_2ff. B29C_3 b29c_3ff. B29C_4 b29c_4ff.
         B29C_5 b29c_5ff. B29C_6 b29c_6ff. B29C_7 b29c_7ff.
         B29C_8 b29c_8ff. B29C_9 b29c_9ff. B29C_10 b29c_10f.
         B29C_11 b29c_11f. B29C_12 b29c_12f. B29C_13 b29c_13f.
         B29C_14 b29c_14f. B30A b30a. B30B b30b.
         B30C_1 b30c_1ff. B30C_2 b30c_2ff. B30C_3 b30c_3ff.
         B30C_4 b30c_4ff. B30C_5 b30c_5ff. B30C_6 b30c_6ff.
         B30C_7 b30c_7ff. B30C_8 b30c_8ff. B30C_9 b30c_9ff.
         B30C_10 b30c_10f. B30C_11 b30c_11f. B30C_12 b30c_12f.
         B30C_13 b30c_13f. B30C_14 b30c_14f. B31A b31a.
         B31B b31b. B31C_1 b31c_1ff. B31C_2 b31c_2ff.
         B31C_3 b31c_3ff. B31C_4 b31c_4ff. B31C_5 b31c_5ff.
         B31C_6 b31c_6ff. B31C_7 b31c_7ff. B31C_8 b31c_8ff.
         B31C_9 b31c_9ff. B31C_10 b31c_10f. B31C_11 b31c_11f.
         B31C_12 b31c_12f. B31C_13 b31c_13f. B31C_14 b31c_14f.
         B32A b32a. B32B b32b. B32C_1 b32c_1ff.
         B32C_2 b32c_2ff. B32C_3 b32c_3ff. B32C_4 b32c_4ff.
         B32C_5 b32c_5ff. B32C_6 b32c_6ff. B32C_7 b32c_7ff.
         B32C_8 b32c_8ff. B32C_9 b32c_9ff. B32C_10 b32c_10f.
         B32C_11 b32c_11f. B32C_12 b32c_12f. B32C_13 b32c_13f.
         B32C_14 b32c_14f. B33A b33a. B33B b33b.
         B33C_1 b33c_1ff. B33C_2 b33c_2ff. B33C_3 b33c_3ff.
         B33C_4 b33c_4ff. B33C_5 b33c_5ff. B33C_6 b33c_6ff.
         B33C_7 b33c_7ff. B33C_8 b33c_8ff. B33C_9 b33c_9ff.
         B33C_10 b33c_10f. B33C_11 b33c_11f. B33C_12 b33c_12f.
         B33C_13 b33c_13f. B33C_14 b33c_14f. B34A b34a.
         B34B b34b. B34C b34c. B35 b35fffff.
         B35AA b35aa. B35AB b35ab. B35AC b35ac.
         B36 b36fffff. B41_1 b41_1fff. B41_2 b41_2fff.
         B41_3 b41_3fff. B41_4 b41_4fff. B41_5 b41_5fff.
         B41_6 b41_6fff. B41_7 b41_7fff. B41_8 b41_8fff.
         B41_9 b41_9fff. B41_10 b41_10ff. B41_11 b41_11ff.
         B41_12 b41_12ff. B41_13 b41_13ff. B42 b42fffff.
         B43 b43fffff. B44 b44fffff. B44A b44a.
         B45 b45fffff. B46 b46fffff. B46AA b46aa.
         B46AB b46ab. B46AC b46ac. B47A b47a.
         B47B b47b. B47C b47c. B47D b47d.
         B47E b47e. B47F b47f. B47G b47g.
         B47H b47h. B47I b47i. B48 b48fffff.
         C1AINHAL c1ainhal. C1AALCOH c1aalcoh. C1AMARIJ c1amarij.
         C1ACRACK c1acrack. C1ACOCAI c1acocai. C1APCP c1apcp.
         C1AHALLU c1ahallu. C1AHEROI c1aheroi. C1AMTHDO c1amthdo.
         C1AONARC c1aonarc. C1AMETHA c1ametha. C1ADOWNR c1adownr.
         C1AODRUG c1aodrug. C2INHAL c2inhal. C3INHAL c3inhal.
         C3AINHAL c3ainhal. C4INHAL c4inhal. C5INHAL c5inhal.
         C6INHAL c6inhal. C7INHAL c7inhal. C8INHAL c8inhal.
         C8AINHAL c8ainhal. C9INHAL c9inhal. C2ALCOH c2alcoh.
         C3ALCOH c3alcoh. C3AALCOH c3aalcoh. C4ALCOH c4alcoh.
         C5ALCOH c5alcoh. C6ALCOH c6alcoh. C7ALCOH c7alcoh.
         C8ALCOH c8alcoh. C8AALCOH c8aalcoh. C9ALCOH c9alcoh.
         C2MARIJ c2marij. C3MARIJ c3marij. C3AMARIJ c3amarij.
         C4MARIJ c4marij. C5MARIJ c5marij. C6MARIJ c6marij.
         C7MARIJ c7marij. C8MARIJ c8marij. C8AMARIJ c8amarij.
         C9MARIJ c9marij. C2CRACK c2crack. C3CRACK c3crack.
         C3ACRACK c3acrack. C4CRACK c4crack. C5CRACK c5crack.
         C6CRACK c6crack. C7CRACK c7crack. C8CRACK c8crack.
         C8ACRACK c8acrack. C9CRACK c9crack. C2COCAI c2cocai.
         C3COCAI c3cocai. C3ACOCAI c3acocai. C4COCAI c4cocai.
         C5COCAI c5cocai. C6COCAI c6cocai. C7COCAI c7cocai.
         C8COCAI c8cocai. C8ACOCAI c8acocai. C9COCAI c9cocai.
         C2PCP c2pcp. C3PCP c3pcp. C3APCP c3apcp.
         C4PCP c4pcp. C5PCP c5pcp. C6PCP c6pcp.
         C7PCP c7pcp. C8PCP c8pcp. C8APCP c8apcp.
         C9PCP c9pcp. C2HALLU c2hallu. C3HALLU c3hallu.
         C3AHALLU c3ahallu. C4HALLU c4hallu. C5HALLU c5hallu.
         C6HALLU c6hallu. C7HALLU c7hallu. C8HALLU c8hallu.
         C8AHALLU c8ahallu. C9HALLU c9hallu. C2HEROI c2heroi.
         C3HEROI c3heroi. C3AHEROI c3aheroi. C4HEROI c4heroi.
         C5HEROI c5heroi. C6HEROI c6heroi. C7HEROI c7heroi.
         C8HEROI c8heroi. C8AHEROI c8aheroi. C9HEROI c9heroi.
         C2MTHDO c2mthdo. C3MTHDO c3mthdo. C3AMTHDO c3amthdo.
         C4MTHDO c4mthdo. C5MTHDO c5mthdo. C6MTHDO c6mthdo.
         C7MTHDO c7mthdo. C8MTHDO c8mthdo. C8AMTHDO c8amthdo.
         C9MTHDO c9mthdo. C2ONARC c2onarc. C3ONARC c3onarc.
         C3AONARC c3aonarc. C4ONARC c4onarc. C5ONARC c5onarc.
         C6ONARC c6onarc. C7ONARC c7onarc. C8ONARC c8onarc.
         C8AONARC c8aonarc. C9ONARC c9onarc. C2METHA c2metha.
         C3METHA c3metha. C3AMETHA c3ametha. C4METHA c4metha.
         C5METHA c5metha. C6METHA c6metha. C7METHA c7metha.
         C8METHA c8metha. C8AMETHA c8ametha. C9METHA c9metha.
         C2DOWNR c2downr. C3DOWNR c3downr. C3ADOWNR c3adownr.
         C4DOWNR c4downr. C5DOWNR c5downr. C6DOWNR c6downr.
         C7DOWNR c7downr. C8DOWNR c8downr. C8ADOWNR c8adownr.
         C9DOWNR c9downr. C2ODRUG c2odrug. C3ODRUG c3odrug.
         C3AODRUG c3aodrug. C4ODRUG c4odrug. C5ODRUG c5odrug.
         C6ODRUG c6odrug. C7ODRUG c7odrug. C8ODRUG c8odrug.
         C8AODRUG c8aodrug. C9ODRUG c9odrug. C10 c10fffff.
         C11 c11fffff. C12_1 c12_1fff. C13_1 c13_1fff.
         C13_1A c13_1a. C12_2 c12_2fff. C13_2 c13_2fff.
         C13_2A c13_2a. C12_3 c12_3fff. C13_3 c13_3fff.
         C13_3A c13_3a. C15INHA c15inha. C15ALCO c15alco.
         C15MARI c15mari. C15CRCK c15crck. C15COCA c15coca.
         C15PCP c15pcp. C15HALU c15halu. C15HERO c15hero.
         C15MTDO c15mtdo. C15ONRC c15onrc. C15METH c15meth.
         C15DOWN c15down. C15OTHR c15othr. C16INHA c16inha.
         C17INHA c17inha. C18INHA c18inha. C18AINHA c18ainha.
         C19INHA c19inha. C19AINHA c19ainha. C20INHA c20inha.
         C20AINHA c20ainha. C21INHA c21inha. C16ALCO c16alco.
         C17ALCO c17alco. C18ALCO c18alco. C18AALCO c18aalco.
         C19ALCO c19alco. C19AALCO c19aalco. C20ALCO c20alco.
         C20AALCO c20aalco. C21ALCO c21alco. C16MARI c16mari.
         C17MARI c17mari. C18MARI c18mari. C18AMARI c18amari.
         C19MARI c19mari. C19AMARI c19amari. C20MARI c20mari.
         C20AMARI c20amari. C21MARI c21mari. C16CRCK c16crck.
         C17CRCK c17crck. C18CRCK c18crck. C18ACRCK c18acrck.
         C19CRCK c19crck. C19ACRCK c19acrck. C20CRCK c20crck.
         C20ACRCK c20acrck. C21CRCK c21crck. C16COCA c16coca.
         C17COCA c17coca. C18COCA c18coca. C18ACOCA c18acoca.
         C19COCA c19coca. C19ACOCA c19acoca. C20COCA c20coca.
         C20ACOCA c20acoca. C21COCA c21coca. C16PCP c16pcp.
         C17PCP c17pcp. C18PCP c18pcp. C18APCP c18apcp.
         C19PCP c19pcp. C19APCP c19apcp. C20PCP c20pcp.
         C20APCP c20apcp. C21PCP c21pcp. C16HALU c16halu.
         C17HALU c17halu. C18HALU c18halu. C18AHALU c18ahalu.
         C19HALU c19halu. C19AHALU c19ahalu. C20HALU c20halu.
         C20AHALU c20ahalu. C21HALU c21halu. C16HERO c16hero.
         C17HERO c17hero. C18HERO c18hero. C18AHERO c18ahero.
         C19HERO c19hero. C19AHERO c19ahero. C20HERO c20hero.
         C20AHERO c20ahero. C21HERO c21hero. C16MTDO c16mtdo.
         C17MTDO c17mtdo. C18MTDO c18mtdo. C18AMTDO c18amtdo.
         C19MTDO c19mtdo. C19AMTDO c19amtdo. C20MTDO c20mtdo.
         C20AMTDO c20amtdo. C21MTDO c21mtdo. C16ONRC c16onrc.
         C17ONRC c17onrc. C18ONRC c18onrc. C18AONRC c18aonrc.
         C19ONRC c19onrc. C19AONRC c19aonrc. C20ONRC c20onrc.
         C20AONRC c20aonrc. C21ONRC c21onrc. C16METH c16meth.
         C17METH c17meth. C18METH c18meth. C18AMETH c18ameth.
         C19METH c19meth. C19AMETH c19ameth. C20METH c20meth.
         C20AMETH c20ameth. C21METH c21meth. C16DOWN c16down.
         C17DOWN c17down. C18DOWN c18down. C18ADOWN c18adown.
         C19DOWN c19down. C19ADOWN c19adown. C20DOWN c20down.
         C20ADOWN c20adown. C21DOWN c21down. C16OTHR c16othr.
         C17OTHR c17othr. C18OTHR c18othr. C18AOTHR c18aothr.
         C19OTHR c19othr. C19AOTHR c19aothr. C20OTHR c20othr.
         C20AOTHR c20aothr. C21OTHR c21othr. C22 c22fffff.
         C23 c23fffff. C24_1 c24_1fff. C25_1 c25_1fff.
         C25_1A c25_1a. C24_2 c24_2fff. C25_2 c25_2fff.
         C25_2A c25_2a. C24_3 c24_3fff. C25_3 c25_3fff.
         C25_3A c25_3a. C27 c27fffff. C27A c27a.
         C27B c27b. C28 c28fffff. C28A c28a.
         C28B c28b. C28CA c28ca. C28CB c28cb.
         C28CC c28cc. C29 c29fffff. C29A c29a.
         D1 d1ffffff. D1A d1a. D2 d2ffffff.
         D3 d3ffffff. D4 d4ffffff. D5 d5ffffff.
         D6A d6a. D6B d6b. D6C d6c.
         D6D d6d. D6E d6e. D6F d6f.
         D6G d6g. D7 d7ffffff. D7AA d7aa.
         D7BA d7ba. D7AB d7ab. D7BB d7bb.
         D7AC d7ac. D7BC d7bc. D7AD d7ad.
         D7BD d7bd. D7AE d7ae. D7BE d7be.
         D7AF d7af. D7BF d7bf. D7AG d7ag.
         D7BG d7bg. D8 d8ffffff. D9 d9ffffff.
         D9A_1 d9a_1fff. D9A_2 d9a_2fff. D9A_3 d9a_3fff.
         D9A_4 d9a_4fff. D9A_5 d9a_5fff. D9A_6 d9a_6fff.
         D9A_7 d9a_7fff. D9A_8 d9a_8fff. D9A_9 d9a_9fff.
         D9A_10 d9a_10ff. D9A_11 d9a_11ff. D9A_12 d9a_12ff.
         D9A_13 d9a_13ff. D9A_14 d9a_14ff. D9A_15 d9a_15ff.
         D10 d10fffff. D10A d10a. D11 d11fffff.
         D12A d12a. D13A d13a. D13ANUM d13anum.
         D12B d12b. D13B d13b. D13BNUM d13bnum.
         D12C d12c. D13C d13c. D13CNUM d13cnum.
         D12D d12d. D13D d13d. D13DNUM d13dnum.
         D12E d12e. D13E d13e. D13ENUM d13enum.
         D12F d12f. D13F d13f. D13FNUM d13fnum.
         D12G d12g. D13G d13g. D13GNUM d13gnum.
         D14 d14fffff. D14A d14a. D15 d15fffff.
         D15A d15a. D15B d15b. D16A d16a.
         D17A d17a. D16B d16b. D17B d17b.
         D16C d16c. D17C d17c. D16D d16d.
         D17D d17d. D16E d16e. D17E d17e.
         D16F d16f. D17F d17f. D16G d16g.
         D17G d17g. D18 d18fffff. D19 d19fffff.
         D20 d20fffff. D20A d20a. D20B d20b.
         D20C d20c. D20D d20d. D20E d20e.
         D20F d20f. D21 d21fffff. D21A d21a.
         D21B d21b. D21C d21c. D21D d21d.
         D21E d21e. D21F d21f. D22 d22fffff.
         D22A d22a. D22B d22b. D22C d22c.
         D22D d22d. D22E d22e. D22F d22f.
         D23 d23fffff. D23A d23a. D23B d23b.
         D23C d23c. D23D d23d. D23E d23e.
         D23F d23f. D24 d24fffff. D24A d24a.
         D24B d24b. D24C d24c. D24D d24d.
         D24E d24e. D24F d24f. D25 d25fffff.
         D25A d25a. D25B d25b. D25C d25c.
         D25D d25d. D25E d25e. D25F d25f.
         D26 d26fffff. D26A d26a. D26B d26b.
         D26C d26c. D26D d26d. D26E d26e.
         D26F d26f. D27 d27fffff. D27A d27a.
         D27B d27b. D27C d27c. D27D d27d.
         D27E d27e. D27F d27f. D28 d28fffff.
         D28A d28a. D28B d28b. D28C d28c.
         D28D d28d. D28E d28e. D28F d28f.
         D29 d29fffff. D29A d29a. D29B d29b.
         D29C d29c. D29D d29d. D29E d29e.
         D29F d29f. D30 d30fffff. D30A d30a.
         D30B d30b. D30C d30c. D30D d30d.
         D30E d30e. D30F d30f. D31 d31fffff.
         D31A d31a. D31B d31b. D31C d31c.
         D31D d31d. D31E d31e. D31F d31f.
         D32 d32fffff. D32A d32a. D32B d32b.
         D32C d32c. D32D d32d. D32E d32e.
         D32F d32f. D33 d33fffff. D33A d33a.
         D33B d33b. D33C d33c. D33D d33d.
         D33E d33e. D33F d33f. D34 d34fffff.
         D34A d34a. D34B d34b. D34C d34c.
         D34D d34d. D34E d34e. D34F d34f.
         D35 d35fffff. D35A d35a. D35B d35b.
         D35C d35c. D35D d35d. D35E d35e.
         D35F d35f. D36 d36fffff. D36AA d36aa.
         D36AB d36ab. D36AC d36ac. D35AD d35ad.
         E1 e1ffffff. E1A e1a. E2 e2ffffff.
         E3 e3ffffff. E4MONTH e4month. E4YEAR e4year.
         E5 e5ffffff. E6 e6ffffff. E7 e7ffffff.
         E8A e8a. E8B e8b. E9 e9ffffff.
         E10 e10fffff. F1 f1ffffff. F2 f2ffffff.
         F3 f3ffffff. F3A f3a. F3B f3b.
         F4 f4ffffff. F5 f5ffffff. F5A f5a.
         F6 f6ffffff. F6A f6a. F7 f7ffffff.
         F8 f8ffffff. F8A f8a. F9 f9ffffff.
         F10 f10fffff. F10A f10a. F11 f11fffff.
         F11A f11a. F12 f12fffff. F12A f12a.
         F13 f13fffff. F13A f13a. F13B f13b.
         F13C f13c. F13D f13d. F13E f13e.
         F13F f13f. F14 f14fffff. F14A f14a.
         F15 f15fffff. F15A f15a. F15B f15b.
         F15C f15c. F16 f16fffff. F16A f16a.
         F17 f17fffff. F17A f17a. F17B f17b.
         F17C f17c. F19 f19fffff. F19A_1 f19a_1ff.
         F19A_2 f19a_2ff. F19A_3 f19a_3ff. F19A_4 f19a_4ff.
         F19A_5 f19a_5ff. F19A_6 f19a_6ff. F19A_7 f19a_7ff.
         F19A_8 f19a_8ff. F19A_9 f19a_9ff. F19A_10 f19a_10f.
         F19B_0 f19b_0ff. F19B_1 f19b_1ff. F19B_2 f19b_2ff.
         F19B_3 f19b_3ff. F19B_4 f19b_4ff. F19B_5 f19b_5ff.
         F19B_6 f19b_6ff. F19B_7 f19b_7ff. F19B_8 f19b_8ff.
         F19B_9 f19b_9ff. F19B_10 f19b_10f. F19B_11 f19b_11f.
         F19B_12 f19b_12f. F19B_13 f19b_13f. F19B_14 f19b_14f.
         F19B_15 f19b_15f. F19B_16 f19b_16f. F19B_17 f19b_17f.
         F19C f19c. G1 g1ffffff. G2 g2ffffff.
         G3 g3ffffff. G3A g3a. G3B g3b.
         G4 g4ffffff. G5 g5ffffff. G6 g6ffffff.
         G7 g7ffffff. G8 g8ffffff. G9 g9ffffff.
         G10 g10fffff. G11 g11fffff. G12 g12fffff.
         G13 g13fffff. G14 g14fffff. G15 g15fffff.
         G16 g16fffff. G17 g17fffff. G18 g18fffff.
         G19 g19fffff. G20 g20fffff. G20A g20a.
         G20B g20b. G21 g21fffff. G22 g22fffff.
         G23 g23fffff. G24 g24fffff. G25 g25fffff.
         G26 g26fffff. G27 g27fffff. G28 g28fffff.
         G28A g28a. G28B g28b. G29 g29fffff.
         G30 g30fffff. G31 g31fffff. G32 g32fffff.
         G33 g33fffff. G34 g34fffff. G35 g35fffff.
         G36 g36fffff. G37 g37fffff. G38 g38fffff.
         G39 g39fffff. G40 g40fffff. G41 g41fffff.
         G42 g42fffff. G43 g43fffff. G44 g44fffff.
         G45 g45fffff. G46 g46fffff. G47 g47fffff.
         G48 g48fffff. G49 g49fffff. G50 g50fffff.
         G51A g51a. G51B g51b. G51C g51c.
         G51D g51d. G51E g51e. G51F g51f.
         G51G g51g. G51H g51h. G51I g51i.
         G51J g51j. G51K g51k. G51AA g51aa.
         G51BA g51ba. G51AB g51ab. G51BB g51bb.
         G51AC g51ac. G51BC g51bc. G51AD g51ad.
         G51BD g51bd. G51AE g51ae. G51BE g51be.
         G51AF g51af. G51BF g51bf. G51AG g51ag.
         G51BG g51bg. G51AH g51ah. G51BH g51bh.
         G51AI g51ai. G51BI g51bi. G51AJ g51aj.
         G51BJ g51bj. G51AK g51ak. G51BK g51bk.
         G52 g52fffff. G53 g53fffff. G54 g54fffff.
         G55 g55fffff. G56 g56fffff. G57 g57fffff.
         G58 g58fffff. G59 g59fffff. G60 g60fffff.
         G61 g61fffff. G62 g62fffff. G63 g63fffff.
         G64 g64fffff. G65 g65fffff. G66 g66fffff.
         G67 g67fffff. G68 g68fffff. G69 g69fffff.
         G70 g70fffff. G71 g71fffff. G72 g72fffff.
         G73 g73fffff. G74 g74fffff. G75 g75fffff.
         G76 g76fffff. G77 g77fffff. G78 g78fffff.
         G79 g79fffff. G80 g80fffff. G81 g81fffff.
         G82 g82fffff. G83 g83fffff. G84 g84fffff.
         G86 g86fffff. G87 g87fffff. G88 g88fffff.
         G89 g89fffff. G90 g90fffff. G91 g91fffff.
         G92 g92fffff. G93 g93fffff. G95 g95fffff.
         G96 g96fffff. G97 g97fffff. G98 g98fffff.
         G99 g99fffff. H1 h1ffffff. H2 h2ffffff.
         H3 h3ffffff. H3BDOL h3bdol. H3BRATE h3brate.
         H4 h4ffffff. H4ADOL h4adol. H4ARATE h4arate.
         SAME1ST same1st. H6 h6ffffff. H7 h7ffffff.
         SAME2ND same2nd. H7BDOL h7bdol. H7ARATE h7arate.
         H8 h8ffffff. H8ADOL h8adol. H8ARATE h8arate.
         SAME3RD same3rd. H10 h10fffff. H10A h10a.
         H10BDOL h10bdol. H10BRTE h10brte. SAME4TH same4th.
         H11 h11fffff. H12 h12fffff. H13 h13fffff.
         SAME5TH same5th. H13BDOL h13bdol. H13BRTE h13brte.
         H14 h14fffff. H14ADOL h14adol. H14ARTE h14arte.
         SAME6TH same6th. H15 h15fffff. SAME7TH same7th.
         H15B h15b. H15CDOL h15cdol. H15CRTE h15crte.
         H17 h17fffff. H17A h17a. H17BDOL h17bdol.
         H17BRTE h17brte. SAME8TH same8th. H19 h19fffff.
         H19A_1 h19a_1ff. H19A_2 h19a_2ff. H19A_3 h19a_3ff.
         H19A_4 h19a_4ff. H19A_5 h19a_5ff. H19A_6 h19a_6ff.
         H19A_7 h19a_7ff. H19A_8 h19a_8ff. H19B h19b.
         H21A h21a. H22A h22a. H22ATIM h22atim.
         H21B h21b. H22B h22b. H22BTIM h22btim.
         H21C h21c. H22C h22c. H22CTIM h22ctim.
         H21D h21d. H22D h22d. H22DTIM h22dtim.
         H21E h21e. H22E h22e. H22ETIM h22etim.
         H21F h21f. H22F h22f. H22FTIM h22ftim.
         H21G h21g. H22G h22g. H22GTIM h22gtim.
         H21H h21h. H22H h22h. H22HTIM h22htim.
         PHONE1 phone1ff. PHONE2 phone2ff. PERSON2 person2f.
         PHONE3 phone3ff. ENDYEAR endyear. TOTTIME tottime.
         BOXII boxii. BOXIII boxiii. BOXIV boxiv.
         BOXRECPT boxrecpt. I11A i11a. I11AA i11aa.
         I11AB i11ab. I11B i11b. I11BA i11ba.
         I11BB i11bb. I11C i11c. I11CA i11ca.
         I11CB i11cb. I11D i11d. I11DA i11da.
         I11DB i11db. I11E i11e. I11EA i11ea.
         I11EB i11eb. I11F i11f. I11FA i11fa.
         I11FB i11fb. I11G i11g. I11GA i11ga.
         I11GB i11gb. I11AC i11ac. I11BC i11bc.
         I11CC i11cc. I11DC i11dc. I11EC i11ec.
         I11FC i11fc. I11GC i11gc. D6A_1 d6a_1fff.
         INHAL inhal. ALCOHOL alcohol. MARIJUAN marijuan.
         CRACK crack. COCAINE cocaine. PCP pcp.
         HALLUCIN hallucin. HEROIN heroin. ILLMETH illmeth.
         NARC narc. METHAMPH methamph. DOWNERS downers.
         OTHDRUG othdrug. AGEFINH agefinh. AGEFALC agefalc.
         AGEFMAR agefmar. AGFCRK agfcrk. AGEFCOC agefcoc.
         AGEFPCP agefpcp. AGEFHAL agefhal. AGEFHER agefher.
         AGEFMTH agefmth. AGEFNAR agefnar. AGEFAMP agefamp.
         AGEFDWN agefdwn. AGEFOTH agefoth. USBINH usbinh.
         USBALC usbalc. USBMAR usbmar. USBCRK usbcrk.
         USBCOC usbcoc. USBPCP usbpcp. USBHAL usbhal.
         USBHER usbher. USBMTH usbmth. USBNAR usbnar.
         USBAMP usbamp. USBDWN usbdwn. USBOTH usboth.
         USBDINH usbdinh. USBDALC usbdalc. USBDMAR usbdmar.
         USBDCRK usbdcrk. USBDCOC usbdcoc. USBDPCP usbdpcp.
         USBDHAL usbdhal. USBDHER usbdher. USBDMTH usbdmth.
         USBDNAR usbdnar. USBDAMP usbdamp. USBDDWN usbddwn.
         USBDOTH usbdoth. USAINH usainh. USAALC usaalc.
         USAMAR usamar. USACRK usacrk. USACOC usacoc.
         USAPCP usapcp. USAHAL usahal. USAHER usaher.
         USAMTH usamth. USANAR usanar. USAAMP usaamp.
         USADWN usadwn. USAOTH usaoth. USADINH usadinh.
         USADALC usadalc. USADMAR usadmar. USADCRK usadcrk.
         USADCOC usadcoc. USADPCP usadpcp. USADHAL usadhal.
         USADHER usadher. USADMTH usadmth. USADNAR usadnar.
         USADAMP usadamp. USADDWN usaddwn. USADOTH usadoth.
         USYINH usyinh. USYALC usyalc. USYMAR usymar.
         USYCRK usycrk. USYCOC usycoc. USYPCP usypcp.
         USYHAL usyhal. USYHER usyher. USYMTH usymth.
         USYNAR usynar. USYAMP usyamp. USYDWN usydwn.
         USYOTH usyoth. USYDINH usydinh. USYDALC usydalc.
         USYDMAR usydmar. USYDCRK usydcrk. USYDCOC usydcoc.
         USYDPCP usydpcp. USYDHAL usydhal. USYDHER usydher.
         USYDMTH usydmth. USYDNAR usydnar. USYDAMP usydamp.
         USYDDWN usyddwn. USYDOTH usydoth. USNINH usninh.
         USNALC usnalc. USNMAR usnmar. USNCRK usncrk.
         USNCOC usncoc. USNPCP usnpcp. USNHAL usnhal.
         USNHER usnher. USNMTH usnmth. USNNAR usnnar.
         USNAMP usnamp. USNDWN usndwn. USNOTH usnoth.
         USNMINH usnminh. USNMALC usnmalc. USNMMAR usnmmar.
         USNMCRK usnmcrk. USNMCOC usnmcoc. USNMPCP usnmpcp.
         USNMHAL usnmhal. USNMHER usnmher. USNMMTH usnmmth.
         USNMNAR usnmnar. USNMAMP usnmamp. USNMDWN usnmdwn.
         USNMOTH usnmoth. USMINH usminh. USMALC usmalc.
         USMMAR usmmar. USMCRK usmcrk. USMCOC usmcoc.
         USMPCP usmpcp. USMHAL usmhal. USMHER usmher.
         USMMTH usmmth. USMNAR usmnar. USMAMP usmamp.
         USMDWN usmdwn. USMOTH usmoth. USBSEC usbsec.
         USASEC usasec. USBANY usbany. USAANY usaany.
         TRTYPE trtype. LOS los. LOSCAT loscat.
         RACE race. DISAGE disage. DISAGE2 disage2f.
         PRETRT pretrt. COMPTRT comptrt. AFTTRT afttrt.
         HELPTRT helptrt.  ;

RUN ;
